"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.KafkaEnvelope = void 0;
const zod_1 = require("zod");
const errors_js_1 = require("../errors.js");
const kafka_js_1 = require("../schemas/kafka.js");
const envelope_js_1 = require("./envelope.js");
/**
 * Get the event source from the data.
 *
 * Before we can access the event source, we need to parse the data with a minimal schema.
 *
 * @param data - The data to extract the event source from
 */
const extractEventSource = (data) => {
    const verifiedData = zod_1.z
        .object({
        eventSource: zod_1.z.union([
            zod_1.z.literal('aws:kafka'),
            zod_1.z.literal('SelfManagedKafka'),
        ]),
    })
        .parse(data);
    return verifiedData.eventSource;
};
/**
 * Kafka event envelope to extract data within body key
 * The record's body parameter is a string, though it can also be a JSON encoded string.
 * Regardless of its type it'll be parsed into a BaseModel object.
 *
 * Note: Records will be parsed the same way so if model is str,
 * all items in the list will be parsed as str and not as JSON (and vice versa)
 */
exports.KafkaEnvelope = {
    /**
     * This is a discriminator to differentiate whether an envelope returns an array or an object
     * @hidden
     */
    [envelope_js_1.envelopeDiscriminator]: 'array',
    parse(data, schema) {
        const eventSource = extractEventSource(data);
        const parsedEnvelope = eventSource === 'aws:kafka'
            ? kafka_js_1.KafkaMskEventSchema.parse(data)
            : kafka_js_1.KafkaSelfManagedEventSchema.parse(data);
        const values = [];
        for (const topicRecord of Object.values(parsedEnvelope.records)) {
            for (const record of topicRecord) {
                values.push(schema.parse(record.value));
            }
        }
        return values;
    },
    safeParse(data, schema) {
        // manually fetch event source to deside between Msk or SelfManaged
        const eventSource = data.eventSource;
        const parsedEnvelope = eventSource === 'aws:kafka'
            ? kafka_js_1.KafkaMskEventSchema.safeParse(data)
            : kafka_js_1.KafkaSelfManagedEventSchema.safeParse(data);
        if (!parsedEnvelope.success) {
            return {
                success: false,
                error: new errors_js_1.ParseError('Failed to parse Kafka envelope', {
                    cause: parsedEnvelope.error,
                }),
                originalEvent: data,
            };
        }
        const values = [];
        const issues = [];
        for (const [topicKey, topicRecord] of Object.entries(parsedEnvelope.data.records)) {
            for (const record of topicRecord) {
                const parsedRecord = schema.safeParse(record.value);
                if (!parsedRecord.success) {
                    issues.push(...parsedRecord.error.issues.map((issue) => ({
                        ...issue,
                        path: ['records', topicKey, ...issue.path],
                    })));
                }
                values.push(parsedRecord.data);
            }
        }
        return issues.length > 0
            ? {
                success: false,
                error: new errors_js_1.ParseError('Failed to parse Kafka envelope', {
                    cause: new zod_1.ZodError(issues),
                }),
                originalEvent: data,
            }
            : {
                success: true,
                data: values,
            };
    },
};
