"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parse = void 0;
const errors_js_1 = require("./errors.js");
/**
 * Parse the data using the provided schema, envelope and safeParse flag
 *
 * @example
 * ```typescript
 * import { z } from 'zod';
 * import type { SqsEvent, ParsedResult } from '@aws-lambda-powertools/parser/types';
 * import { SqsEnvelope } from '@aws-lambda-powertools/parser/types/envelopes';
 * import { parse } from '@aws-lambda-powertools/parser';
 *
 * const Order = z.object({
 *   orderId: z.string(),
 *   description: z.string(),
 * });
 *
 * const handler = async (event: SqsEvent, context: unknown): Promise<unknown> => {
 *   const parsedEvent = parse(event, SqsEnvelope, Order);
 *
 *   const parsedSafe: ParsedResult<SqsEnvelope> = parse(event, SqsEnvelope, Order, true)
 * }
 * @param data the data to parse
 * @param envelope the envelope to use, can be undefined
 * @param schema the schema to use
 * @param safeParse whether to use safeParse or not, if true it will return a ParsedResult with the original event if the parsing fails
 */
const parse = (data, envelope, schema, safeParse) => {
    if (envelope && safeParse) {
        return envelope.safeParse(data, schema);
    }
    if (envelope) {
        return envelope.parse(data, schema);
    }
    if (safeParse) {
        return safeParseSchema(data, schema);
    }
    try {
        return schema.parse(data);
    }
    catch (error) {
        throw new errors_js_1.ParseError('Failed to parse schema', { cause: error });
    }
};
exports.parse = parse;
/**
 * Parse the data safely using the provided schema.
 * This function will not throw an error if the parsing fails, instead it will return a ParsedResultError with the original event.
 * Otherwise, it will return ParsedResultSuccess with the parsed data.
 * @param data the data to parse
 * @param schema the zod schema to use
 */
const safeParseSchema = (data, schema) => {
    const result = schema.safeParse(data);
    return result.success
        ? result
        : {
            success: false,
            error: new errors_js_1.ParseError('Failed to parse schema safely', {
                cause: result.error,
            }),
            originalEvent: data,
        };
};
