import { z } from 'zod';
/**
 * A zod schema for an API Gateway HTTP API Request Authorizer
 *
 * If Lambda authorizer is used, the `lambda` property will be set to an object
 * containing the `context` object returned by the Lambda authorizer function.
 * If no `context` object is returned, the `lambda` property will be set to `null`.
 *
 * If JWT authorizer is used, the `jwt` property will be set to an object
 * containing the `claims` object returned by the JWT authorizer function. Optionally,
 * the `scopes` property will be set to an array of scopes returned by the JWT authorizer.
 *
 * @example
 * ```json
 * {
 *   "jwt": {
 *     "claims": {
 *       "claim1": "value1",
 *       "claim2": "value2"
 *     },
 *     "scopes": [
 *       "scope1",
 *       "scope2"
 *     ]
 *   }
 * }
 * ```
 *
 * If IAM authorizer is used, the `iam` property will be set to an object
 * containing the details of the IAM user making the request.
 *
 * @see {@link https://docs.aws.amazon.com/apigateway/latest/developerguide/http-api-access-control.html}
 */
declare const APIGatewayRequestAuthorizerV2Schema: z.ZodObject<{
    jwt: z.ZodOptional<z.ZodObject<{
        claims: z.ZodRecord<z.ZodString, z.ZodAny>;
        scopes: z.ZodNullable<z.ZodArray<z.ZodString, "many">>;
    }, "strip", z.ZodTypeAny, {
        claims: Record<string, any>;
        scopes: string[] | null;
    }, {
        claims: Record<string, any>;
        scopes: string[] | null;
    }>>;
    iam: z.ZodOptional<z.ZodObject<{
        accessKey: z.ZodOptional<z.ZodString>;
        accountId: z.ZodOptional<z.ZodString>;
        callerId: z.ZodOptional<z.ZodString>;
        principalOrgId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        userArn: z.ZodOptional<z.ZodString>;
        userId: z.ZodOptional<z.ZodString>;
        cognitoIdentity: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            amr: z.ZodArray<z.ZodString, "many">;
            identityId: z.ZodString;
            identityPoolId: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            amr: string[];
            identityId: string;
            identityPoolId: string;
        }, {
            amr: string[];
            identityId: string;
            identityPoolId: string;
        }>>>;
    }, "strip", z.ZodTypeAny, {
        accessKey?: string | undefined;
        accountId?: string | undefined;
        principalOrgId?: string | null | undefined;
        userArn?: string | undefined;
        callerId?: string | undefined;
        userId?: string | undefined;
        cognitoIdentity?: {
            amr: string[];
            identityId: string;
            identityPoolId: string;
        } | null | undefined;
    }, {
        accessKey?: string | undefined;
        accountId?: string | undefined;
        principalOrgId?: string | null | undefined;
        userArn?: string | undefined;
        callerId?: string | undefined;
        userId?: string | undefined;
        cognitoIdentity?: {
            amr: string[];
            identityId: string;
            identityPoolId: string;
        } | null | undefined;
    }>>;
    lambda: z.ZodOptional<z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodAny>>>;
}, "strip", z.ZodTypeAny, {
    jwt?: {
        claims: Record<string, any>;
        scopes: string[] | null;
    } | undefined;
    iam?: {
        accessKey?: string | undefined;
        accountId?: string | undefined;
        principalOrgId?: string | null | undefined;
        userArn?: string | undefined;
        callerId?: string | undefined;
        userId?: string | undefined;
        cognitoIdentity?: {
            amr: string[];
            identityId: string;
            identityPoolId: string;
        } | null | undefined;
    } | undefined;
    lambda?: Record<string, any> | null | undefined;
}, {
    jwt?: {
        claims: Record<string, any>;
        scopes: string[] | null;
    } | undefined;
    iam?: {
        accessKey?: string | undefined;
        accountId?: string | undefined;
        principalOrgId?: string | null | undefined;
        userArn?: string | undefined;
        callerId?: string | undefined;
        userId?: string | undefined;
        cognitoIdentity?: {
            amr: string[];
            identityId: string;
            identityPoolId: string;
        } | null | undefined;
    } | undefined;
    lambda?: Record<string, any> | null | undefined;
}>;
/**
 * A zod schema for an API Gateway HTTP API Request Context
 *
 * @example
 * ```json
 * {
 *   "accountId": "123456789012",
 *   "apiId": "api-id",
 *   "authentication": {}
 *   "domainName": "id.execute-api.us-east-1.amazonaws.com",
 *   "domainPrefix": "id",
 *   "http": {
 *     "method": "POST",
 *     "path": "/my/path",
 *     "protocol": "HTTP/1.1",
 *     "sourceIp": "...",
 *     "userAgent": "..."
 *   },
 *   "requestId": "...",
 *   "routeKey": "$default",
 *   "stage": "$default",
 *   "time": "12/Mar/2020:19:03:58 +0000",
 *   "timeEpoch": 1583348638390
 * }
 * ```
 */
declare const APIGatewayRequestContextV2Schema: z.ZodObject<{
    accountId: z.ZodString;
    apiId: z.ZodString;
    authorizer: z.ZodOptional<z.ZodObject<{
        jwt: z.ZodOptional<z.ZodObject<{
            claims: z.ZodRecord<z.ZodString, z.ZodAny>;
            scopes: z.ZodNullable<z.ZodArray<z.ZodString, "many">>;
        }, "strip", z.ZodTypeAny, {
            claims: Record<string, any>;
            scopes: string[] | null;
        }, {
            claims: Record<string, any>;
            scopes: string[] | null;
        }>>;
        iam: z.ZodOptional<z.ZodObject<{
            accessKey: z.ZodOptional<z.ZodString>;
            accountId: z.ZodOptional<z.ZodString>;
            callerId: z.ZodOptional<z.ZodString>;
            principalOrgId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            userArn: z.ZodOptional<z.ZodString>;
            userId: z.ZodOptional<z.ZodString>;
            cognitoIdentity: z.ZodOptional<z.ZodNullable<z.ZodObject<{
                amr: z.ZodArray<z.ZodString, "many">;
                identityId: z.ZodString;
                identityPoolId: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                amr: string[];
                identityId: string;
                identityPoolId: string;
            }, {
                amr: string[];
                identityId: string;
                identityPoolId: string;
            }>>>;
        }, "strip", z.ZodTypeAny, {
            accessKey?: string | undefined;
            accountId?: string | undefined;
            principalOrgId?: string | null | undefined;
            userArn?: string | undefined;
            callerId?: string | undefined;
            userId?: string | undefined;
            cognitoIdentity?: {
                amr: string[];
                identityId: string;
                identityPoolId: string;
            } | null | undefined;
        }, {
            accessKey?: string | undefined;
            accountId?: string | undefined;
            principalOrgId?: string | null | undefined;
            userArn?: string | undefined;
            callerId?: string | undefined;
            userId?: string | undefined;
            cognitoIdentity?: {
                amr: string[];
                identityId: string;
                identityPoolId: string;
            } | null | undefined;
        }>>;
        lambda: z.ZodOptional<z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    }, "strip", z.ZodTypeAny, {
        jwt?: {
            claims: Record<string, any>;
            scopes: string[] | null;
        } | undefined;
        iam?: {
            accessKey?: string | undefined;
            accountId?: string | undefined;
            principalOrgId?: string | null | undefined;
            userArn?: string | undefined;
            callerId?: string | undefined;
            userId?: string | undefined;
            cognitoIdentity?: {
                amr: string[];
                identityId: string;
                identityPoolId: string;
            } | null | undefined;
        } | undefined;
        lambda?: Record<string, any> | null | undefined;
    }, {
        jwt?: {
            claims: Record<string, any>;
            scopes: string[] | null;
        } | undefined;
        iam?: {
            accessKey?: string | undefined;
            accountId?: string | undefined;
            principalOrgId?: string | null | undefined;
            userArn?: string | undefined;
            callerId?: string | undefined;
            userId?: string | undefined;
            cognitoIdentity?: {
                amr: string[];
                identityId: string;
                identityPoolId: string;
            } | null | undefined;
        } | undefined;
        lambda?: Record<string, any> | null | undefined;
    }>>;
    authentication: z.ZodOptional<z.ZodNullable<z.ZodObject<{
        clientCert: z.ZodOptional<z.ZodObject<{
            clientCertPem: z.ZodString;
            subjectDN: z.ZodString;
            issuerDN: z.ZodString;
            serialNumber: z.ZodString;
            validity: z.ZodObject<{
                notBefore: z.ZodString;
                notAfter: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                notBefore: string;
                notAfter: string;
            }, {
                notBefore: string;
                notAfter: string;
            }>;
        }, "strip", z.ZodTypeAny, {
            clientCertPem: string;
            subjectDN: string;
            issuerDN: string;
            serialNumber: string;
            validity: {
                notBefore: string;
                notAfter: string;
            };
        }, {
            clientCertPem: string;
            subjectDN: string;
            issuerDN: string;
            serialNumber: string;
            validity: {
                notBefore: string;
                notAfter: string;
            };
        }>>;
    }, "strip", z.ZodTypeAny, {
        clientCert?: {
            clientCertPem: string;
            subjectDN: string;
            issuerDN: string;
            serialNumber: string;
            validity: {
                notBefore: string;
                notAfter: string;
            };
        } | undefined;
    }, {
        clientCert?: {
            clientCertPem: string;
            subjectDN: string;
            issuerDN: string;
            serialNumber: string;
            validity: {
                notBefore: string;
                notAfter: string;
            };
        } | undefined;
    }>>>;
    domainName: z.ZodString;
    domainPrefix: z.ZodString;
    http: z.ZodObject<{
        method: z.ZodEnum<["GET", "POST", "PUT", "PATCH", "DELETE", "HEAD", "OPTIONS"]>;
        path: z.ZodString;
        protocol: z.ZodString;
        sourceIp: z.ZodString;
        userAgent: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        path: string;
        sourceIp: string;
        userAgent: string;
        protocol: string;
        method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
    }, {
        path: string;
        sourceIp: string;
        userAgent: string;
        protocol: string;
        method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
    }>;
    requestId: z.ZodString;
    routeKey: z.ZodString;
    stage: z.ZodString;
    time: z.ZodString;
    timeEpoch: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    time: string;
    accountId: string;
    apiId: string;
    stage: string;
    requestId: string;
    domainName: string;
    domainPrefix: string;
    routeKey: string;
    http: {
        path: string;
        sourceIp: string;
        userAgent: string;
        protocol: string;
        method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
    };
    timeEpoch: number;
    authorizer?: {
        jwt?: {
            claims: Record<string, any>;
            scopes: string[] | null;
        } | undefined;
        iam?: {
            accessKey?: string | undefined;
            accountId?: string | undefined;
            principalOrgId?: string | null | undefined;
            userArn?: string | undefined;
            callerId?: string | undefined;
            userId?: string | undefined;
            cognitoIdentity?: {
                amr: string[];
                identityId: string;
                identityPoolId: string;
            } | null | undefined;
        } | undefined;
        lambda?: Record<string, any> | null | undefined;
    } | undefined;
    authentication?: {
        clientCert?: {
            clientCertPem: string;
            subjectDN: string;
            issuerDN: string;
            serialNumber: string;
            validity: {
                notBefore: string;
                notAfter: string;
            };
        } | undefined;
    } | null | undefined;
}, {
    time: string;
    accountId: string;
    apiId: string;
    stage: string;
    requestId: string;
    domainName: string;
    domainPrefix: string;
    routeKey: string;
    http: {
        path: string;
        sourceIp: string;
        userAgent: string;
        protocol: string;
        method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
    };
    timeEpoch: number;
    authorizer?: {
        jwt?: {
            claims: Record<string, any>;
            scopes: string[] | null;
        } | undefined;
        iam?: {
            accessKey?: string | undefined;
            accountId?: string | undefined;
            principalOrgId?: string | null | undefined;
            userArn?: string | undefined;
            callerId?: string | undefined;
            userId?: string | undefined;
            cognitoIdentity?: {
                amr: string[];
                identityId: string;
                identityPoolId: string;
            } | null | undefined;
        } | undefined;
        lambda?: Record<string, any> | null | undefined;
    } | undefined;
    authentication?: {
        clientCert?: {
            clientCertPem: string;
            subjectDN: string;
            issuerDN: string;
            serialNumber: string;
            validity: {
                notBefore: string;
                notAfter: string;
            };
        } | undefined;
    } | null | undefined;
}>;
/**
 * A zod schema for an API Gateway HTTP API Proxy event
 *
 * @example
 * ```json
 * {
 *   "version": "2.0",
 *   "routeKey": "$default",
 *   "rawPath": "/my/path",
 *   "rawQueryString": "parameter1=value1&parameter1=value2&parameter2=value",
 *   "cookies": ["cookie1", "cookie2"],
 *   "headers": {
 *     "header1": "value1",
 *     "header2": "value1,value2"
 *   },
 *   "queryStringParameters": {
 *     "parameter1": "value1,value2",
 *     "parameter2": "value"
 *   },
 *   "requestContext": {
 *     "accountId": "123456789012",
 *     "apiId": "api-id",
 *     "authentication": {}
 *     "domainName": "id.execute-api.us-east-1.amazonaws.com",
 *     "domainPrefix": "id",
 *     "http": {
 *       "method": "POST",
 *       "path": "/my/path",
 *       "protocol": "HTTP/1.1",
 *       "sourceIp": "...",
 *       "userAgent": "..."
 *     },
 *     "requestId": "...",
 *     "routeKey": "$default",
 *     "stage": "$default",
 *     "time": "12/Mar/2020:19:03:58 +0000",
 *     "timeEpoch": 1583348638390
 *   },
 *   "body": "Hello from Lambda",
 *   "pathParameters": {},
 *   "isBase64Encoded": false,
 *   "stageVariables": {}
 * }
 * ```
 *
 * @see {@link https://docs.aws.amazon.com/apigateway/latest/developerguide/http-api-develop-integrations-lambda.html}
 */
declare const APIGatewayProxyEventV2Schema: z.ZodObject<{
    version: z.ZodString;
    routeKey: z.ZodString;
    rawPath: z.ZodString;
    rawQueryString: z.ZodString;
    cookies: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    headers: z.ZodRecord<z.ZodString, z.ZodString>;
    queryStringParameters: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
    requestContext: z.ZodObject<{
        accountId: z.ZodString;
        apiId: z.ZodString;
        authorizer: z.ZodOptional<z.ZodObject<{
            jwt: z.ZodOptional<z.ZodObject<{
                claims: z.ZodRecord<z.ZodString, z.ZodAny>;
                scopes: z.ZodNullable<z.ZodArray<z.ZodString, "many">>;
            }, "strip", z.ZodTypeAny, {
                claims: Record<string, any>;
                scopes: string[] | null;
            }, {
                claims: Record<string, any>;
                scopes: string[] | null;
            }>>;
            iam: z.ZodOptional<z.ZodObject<{
                accessKey: z.ZodOptional<z.ZodString>;
                accountId: z.ZodOptional<z.ZodString>;
                callerId: z.ZodOptional<z.ZodString>;
                principalOrgId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
                userArn: z.ZodOptional<z.ZodString>;
                userId: z.ZodOptional<z.ZodString>;
                cognitoIdentity: z.ZodOptional<z.ZodNullable<z.ZodObject<{
                    amr: z.ZodArray<z.ZodString, "many">;
                    identityId: z.ZodString;
                    identityPoolId: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                }, {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                }>>>;
            }, "strip", z.ZodTypeAny, {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            }, {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            }>>;
            lambda: z.ZodOptional<z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodAny>>>;
        }, "strip", z.ZodTypeAny, {
            jwt?: {
                claims: Record<string, any>;
                scopes: string[] | null;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | null | undefined;
        }, {
            jwt?: {
                claims: Record<string, any>;
                scopes: string[] | null;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | null | undefined;
        }>>;
        authentication: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            clientCert: z.ZodOptional<z.ZodObject<{
                clientCertPem: z.ZodString;
                subjectDN: z.ZodString;
                issuerDN: z.ZodString;
                serialNumber: z.ZodString;
                validity: z.ZodObject<{
                    notBefore: z.ZodString;
                    notAfter: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    notBefore: string;
                    notAfter: string;
                }, {
                    notBefore: string;
                    notAfter: string;
                }>;
            }, "strip", z.ZodTypeAny, {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            }, {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            }>>;
        }, "strip", z.ZodTypeAny, {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        }, {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        }>>>;
        domainName: z.ZodString;
        domainPrefix: z.ZodString;
        http: z.ZodObject<{
            method: z.ZodEnum<["GET", "POST", "PUT", "PATCH", "DELETE", "HEAD", "OPTIONS"]>;
            path: z.ZodString;
            protocol: z.ZodString;
            sourceIp: z.ZodString;
            userAgent: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        }, {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        }>;
        requestId: z.ZodString;
        routeKey: z.ZodString;
        stage: z.ZodString;
        time: z.ZodString;
        timeEpoch: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        time: string;
        accountId: string;
        apiId: string;
        stage: string;
        requestId: string;
        domainName: string;
        domainPrefix: string;
        routeKey: string;
        http: {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        };
        timeEpoch: number;
        authorizer?: {
            jwt?: {
                claims: Record<string, any>;
                scopes: string[] | null;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | null | undefined;
        } | undefined;
        authentication?: {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        } | null | undefined;
    }, {
        time: string;
        accountId: string;
        apiId: string;
        stage: string;
        requestId: string;
        domainName: string;
        domainPrefix: string;
        routeKey: string;
        http: {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        };
        timeEpoch: number;
        authorizer?: {
            jwt?: {
                claims: Record<string, any>;
                scopes: string[] | null;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | null | undefined;
        } | undefined;
        authentication?: {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        } | null | undefined;
    }>;
    body: z.ZodOptional<z.ZodString>;
    pathParameters: z.ZodOptional<z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodString>>>;
    isBase64Encoded: z.ZodBoolean;
    stageVariables: z.ZodOptional<z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodString>>>;
}, "strip", z.ZodTypeAny, {
    isBase64Encoded: boolean;
    headers: Record<string, string>;
    requestContext: {
        time: string;
        accountId: string;
        apiId: string;
        stage: string;
        requestId: string;
        domainName: string;
        domainPrefix: string;
        routeKey: string;
        http: {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        };
        timeEpoch: number;
        authorizer?: {
            jwt?: {
                claims: Record<string, any>;
                scopes: string[] | null;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | null | undefined;
        } | undefined;
        authentication?: {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        } | null | undefined;
    };
    routeKey: string;
    version: string;
    rawPath: string;
    rawQueryString: string;
    body?: string | undefined;
    queryStringParameters?: Record<string, string> | undefined;
    pathParameters?: Record<string, string> | null | undefined;
    stageVariables?: Record<string, string> | null | undefined;
    cookies?: string[] | undefined;
}, {
    isBase64Encoded: boolean;
    headers: Record<string, string>;
    requestContext: {
        time: string;
        accountId: string;
        apiId: string;
        stage: string;
        requestId: string;
        domainName: string;
        domainPrefix: string;
        routeKey: string;
        http: {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        };
        timeEpoch: number;
        authorizer?: {
            jwt?: {
                claims: Record<string, any>;
                scopes: string[] | null;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | null | undefined;
        } | undefined;
        authentication?: {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        } | null | undefined;
    };
    routeKey: string;
    version: string;
    rawPath: string;
    rawQueryString: string;
    body?: string | undefined;
    queryStringParameters?: Record<string, string> | undefined;
    pathParameters?: Record<string, string> | null | undefined;
    stageVariables?: Record<string, string> | null | undefined;
    cookies?: string[] | undefined;
}>;
/**
 * A zod schema for an API Gateway HTTP API Request Authorizer event
 *
 * @example
 * ```json
 * {
 *   "version": "2.0",
 *   "type": "REQUEST",
 *   "routeArn": "arn:aws:execute-api:us-east-1:123456789012:api-id/stage-name/GET/mydemoresource",
 *   "identitySource": ["user1", "123"],
 *   "routeKey": "$default",
 *   "rawPath": "/mydemoresource",
 *   "rawQueryString": "parameter1=value1&parameter1=value2&parameter2=value",
 *   "cookies": ["cookie1", "cookie2"],
 *   "headers": {
 *     "header1": "value1",
 *     "header2": "value1,value2"
 *   },
 *   "queryStringParameters": {
 *     "parameter1": "value1,value2",
 *     "parameter2": "value"
 *   },
 *   "requestContext": {
 *     "accountId": "123456789012",
 *     "apiId": "api-id",
 *     "authentication": {}
 *     "domainName": "id.execute-api.us-east-1.amazonaws.com",
 *     "domainPrefix": "id",
 *     "http": {
 *       "method": "POST",
 *       "path": "/my/path",
 *       "protocol": "HTTP/1.1",
 *       "sourceIp": "...",
 *       "userAgent": "..."
 *     },
 *     "requestId": "...",
 *     "routeKey": "$default",
 *     "stage": "$default",
 *     "time": "12/Mar/2020:19:03:58 +0000",
 *     "timeEpoch": 1583348638390
 *   },
 *   "pathParameters": {},
 *   "stageVariables": {}
 * }
 * ```
 *
 * @see {@link https://docs.aws.amazon.com/apigateway/latest/developerguide/http-api-lambda-authorizer.html}
 */
declare const APIGatewayRequestAuthorizerEventV2Schema: z.ZodObject<{
    version: z.ZodLiteral<"2.0">;
    type: z.ZodLiteral<"REQUEST">;
    routeArn: z.ZodString;
    identitySource: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
    routeKey: z.ZodString;
    rawPath: z.ZodString;
    rawQueryString: z.ZodString;
    cookies: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
    queryStringParameters: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
    requestContext: z.ZodObject<{
        accountId: z.ZodString;
        apiId: z.ZodString;
        authorizer: z.ZodOptional<z.ZodObject<{
            jwt: z.ZodOptional<z.ZodObject<{
                claims: z.ZodRecord<z.ZodString, z.ZodAny>;
                scopes: z.ZodNullable<z.ZodArray<z.ZodString, "many">>;
            }, "strip", z.ZodTypeAny, {
                claims: Record<string, any>;
                scopes: string[] | null;
            }, {
                claims: Record<string, any>;
                scopes: string[] | null;
            }>>;
            iam: z.ZodOptional<z.ZodObject<{
                accessKey: z.ZodOptional<z.ZodString>;
                accountId: z.ZodOptional<z.ZodString>;
                callerId: z.ZodOptional<z.ZodString>;
                principalOrgId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
                userArn: z.ZodOptional<z.ZodString>;
                userId: z.ZodOptional<z.ZodString>;
                cognitoIdentity: z.ZodOptional<z.ZodNullable<z.ZodObject<{
                    amr: z.ZodArray<z.ZodString, "many">;
                    identityId: z.ZodString;
                    identityPoolId: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                }, {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                }>>>;
            }, "strip", z.ZodTypeAny, {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            }, {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            }>>;
            lambda: z.ZodOptional<z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodAny>>>;
        }, "strip", z.ZodTypeAny, {
            jwt?: {
                claims: Record<string, any>;
                scopes: string[] | null;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | null | undefined;
        }, {
            jwt?: {
                claims: Record<string, any>;
                scopes: string[] | null;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | null | undefined;
        }>>;
        authentication: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            clientCert: z.ZodOptional<z.ZodObject<{
                clientCertPem: z.ZodString;
                subjectDN: z.ZodString;
                issuerDN: z.ZodString;
                serialNumber: z.ZodString;
                validity: z.ZodObject<{
                    notBefore: z.ZodString;
                    notAfter: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    notBefore: string;
                    notAfter: string;
                }, {
                    notBefore: string;
                    notAfter: string;
                }>;
            }, "strip", z.ZodTypeAny, {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            }, {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            }>>;
        }, "strip", z.ZodTypeAny, {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        }, {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        }>>>;
        domainName: z.ZodString;
        domainPrefix: z.ZodString;
        http: z.ZodObject<{
            method: z.ZodEnum<["GET", "POST", "PUT", "PATCH", "DELETE", "HEAD", "OPTIONS"]>;
            path: z.ZodString;
            protocol: z.ZodString;
            sourceIp: z.ZodString;
            userAgent: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        }, {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        }>;
        requestId: z.ZodString;
        routeKey: z.ZodString;
        stage: z.ZodString;
        time: z.ZodString;
        timeEpoch: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        time: string;
        accountId: string;
        apiId: string;
        stage: string;
        requestId: string;
        domainName: string;
        domainPrefix: string;
        routeKey: string;
        http: {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        };
        timeEpoch: number;
        authorizer?: {
            jwt?: {
                claims: Record<string, any>;
                scopes: string[] | null;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | null | undefined;
        } | undefined;
        authentication?: {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        } | null | undefined;
    }, {
        time: string;
        accountId: string;
        apiId: string;
        stage: string;
        requestId: string;
        domainName: string;
        domainPrefix: string;
        routeKey: string;
        http: {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        };
        timeEpoch: number;
        authorizer?: {
            jwt?: {
                claims: Record<string, any>;
                scopes: string[] | null;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | null | undefined;
        } | undefined;
        authentication?: {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        } | null | undefined;
    }>;
    pathParameters: z.ZodOptional<z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodString>>>;
    stageVariables: z.ZodOptional<z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodString>>>;
}, "strip", z.ZodTypeAny, {
    type: "REQUEST";
    requestContext: {
        time: string;
        accountId: string;
        apiId: string;
        stage: string;
        requestId: string;
        domainName: string;
        domainPrefix: string;
        routeKey: string;
        http: {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        };
        timeEpoch: number;
        authorizer?: {
            jwt?: {
                claims: Record<string, any>;
                scopes: string[] | null;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | null | undefined;
        } | undefined;
        authentication?: {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        } | null | undefined;
    };
    routeKey: string;
    version: "2.0";
    rawPath: string;
    rawQueryString: string;
    routeArn: string;
    headers?: Record<string, string> | undefined;
    queryStringParameters?: Record<string, string> | undefined;
    pathParameters?: Record<string, string> | null | undefined;
    stageVariables?: Record<string, string> | null | undefined;
    cookies?: string[] | undefined;
    identitySource?: string[] | null | undefined;
}, {
    type: "REQUEST";
    requestContext: {
        time: string;
        accountId: string;
        apiId: string;
        stage: string;
        requestId: string;
        domainName: string;
        domainPrefix: string;
        routeKey: string;
        http: {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        };
        timeEpoch: number;
        authorizer?: {
            jwt?: {
                claims: Record<string, any>;
                scopes: string[] | null;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | null | undefined;
        } | undefined;
        authentication?: {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        } | null | undefined;
    };
    routeKey: string;
    version: "2.0";
    rawPath: string;
    rawQueryString: string;
    routeArn: string;
    headers?: Record<string, string> | undefined;
    queryStringParameters?: Record<string, string> | undefined;
    pathParameters?: Record<string, string> | null | undefined;
    stageVariables?: Record<string, string> | null | undefined;
    cookies?: string[] | undefined;
    identitySource?: string[] | null | undefined;
}>;
export { APIGatewayProxyEventV2Schema, APIGatewayRequestAuthorizerEventV2Schema, APIGatewayRequestAuthorizerV2Schema, APIGatewayRequestContextV2Schema, };
//# sourceMappingURL=api-gatewayv2.d.ts.map