"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SqsAttributesSchema = exports.SqsMsgAttributeDataTypeSchema = exports.SqsMsgAttributeSchema = exports.SqsRecordSchema = exports.SqsSchema = void 0;
const zod_1 = require("zod");
const SqsMsgAttributeDataTypeSchema = zod_1.z.union([
    zod_1.z.literal('String'),
    zod_1.z.literal('Number'),
    zod_1.z.literal('Binary'),
    zod_1.z.string(),
]);
exports.SqsMsgAttributeDataTypeSchema = SqsMsgAttributeDataTypeSchema;
const SqsMsgAttributeSchema = zod_1.z.object({
    stringValue: zod_1.z.string().optional(),
    binaryValue: zod_1.z.string().optional(),
    stringListValues: zod_1.z.array(zod_1.z.string()).optional(),
    binaryListValues: zod_1.z.array(zod_1.z.string()).optional(),
    dataType: SqsMsgAttributeDataTypeSchema,
});
exports.SqsMsgAttributeSchema = SqsMsgAttributeSchema;
const SqsAttributesSchema = zod_1.z.object({
    ApproximateReceiveCount: zod_1.z.string(),
    ApproximateFirstReceiveTimestamp: zod_1.z.string(),
    MessageDeduplicationId: zod_1.z.string().optional(),
    MessageGroupId: zod_1.z.string().optional(),
    SenderId: zod_1.z.string(),
    SentTimestamp: zod_1.z.string(),
    SequenceNumber: zod_1.z.string().optional(),
    AWSTraceHeader: zod_1.z.string().optional(),
    /**
     * Undocumented, but used by AWS to support their re-drive functionality in the console
     */
    DeadLetterQueueSourceArn: zod_1.z.string().optional(),
});
exports.SqsAttributesSchema = SqsAttributesSchema;
/**
 * Zod schema for a SQS record inside an SQS event.
 */
const SqsRecordSchema = zod_1.z.object({
    messageId: zod_1.z.string(),
    receiptHandle: zod_1.z.string(),
    body: zod_1.z.string(),
    attributes: SqsAttributesSchema,
    messageAttributes: zod_1.z.record(zod_1.z.string(), SqsMsgAttributeSchema),
    md5OfBody: zod_1.z.string(),
    md5OfMessageAttributes: zod_1.z.string().optional().nullable(),
    eventSource: zod_1.z.literal('aws:sqs'),
    eventSourceARN: zod_1.z.string(),
    awsRegion: zod_1.z.string(),
});
exports.SqsRecordSchema = SqsRecordSchema;
/**
 * Zod schema for SQS event
 *
 * @example
 * ```json
 * {
 *   "Records": [
 *     {
 *       "messageId": "059f36b4-87a3-44ab-83d2-661975830a7d",
 *       "receiptHandle": "AQEBwJnKyrHigUMZj6rYigCgxlaS3SLy0a...",
 *       "body": "Test message.",
 *       "attributes": {
 *         "ApproximateReceiveCount": "1",
 *         "SentTimestamp": "1545082649183",
 *         "SenderId": "AIDAIENQZJOLO23YVJ4VO",
 *         "ApproximateFirstReceiveTimestamp": "1545082649185"
 *       },
 *       "messageAttributes": {
 *         "testAttr": {
 *           "stringValue": "100",
 *           "binaryValue": "base64Str",
 *           "dataType": "Number"
 *         }
 *       },
 *       "md5OfBody": "e4e68fb7bd0e697a0ae8f1bb342846b3",
 *       "eventSource": "aws:sqs",
 *       "eventSourceARN": "arn:aws:sqs:us-east-2:123456789012:my-queue",
 *       "awsRegion": "us-east-2"
 *     },
 *     {
 *       "messageId": "2e1424d4-f796-459a-8184-9c92662be6da",
 *       "receiptHandle": "AQEBzWwaftRI0KuVm4tP+/7q1rGgNqicHq...",
 *       "body": "{\"message\": \"foo1\"}",
 *       "attributes": {
 *         "ApproximateReceiveCount": "1",
 *         "SentTimestamp": "1545082650636",
 *         "SenderId": "AIDAIENQZJOLO23YVJ4VO",
 *         "ApproximateFirstReceiveTimestamp": "1545082650649",
 *         "DeadLetterQueueSourceArn": "arn:aws:sqs:us-east-2:123456789012:my-queue-dead"
 *       },
 *       "messageAttributes": {},
 *       "md5OfBody": "e4e68fb7bd0e697a0ae8f1bb342846b3",
 *       "eventSource": "aws:sqs",
 *       "eventSourceARN": "arn:aws:sqs:us-east-2:123456789012:my-queue",
 *       "awsRegion": "us-east-2"
 *     }
 *   ]
 * }
 * ```
 *
 * @see {@link types.SqsEvent | SqsEvent}
 * @see {@link https://docs.aws.amazon.com/lambda/latest/dg/with-sqs.html#example-standard-queue-message-event}
 */
const SqsSchema = zod_1.z.object({
    Records: zod_1.z.array(SqsRecordSchema).min(1),
});
exports.SqsSchema = SqsSchema;
