import { z } from 'zod';
/**
 * Zod schema for Application Load Balancer events.
 *
 * @example
 * ```json
 * {
 *   "requestContext": {
 *     "elb": {
 *       "targetGroupArn": "arn:aws:elasticloadbalancing:region:123456789012:targetgroup/my-target-group/6d0ecf831eec9f09"
 *     }
 *   },
 *   "httpMethod": "GET",
 *   "path": "/",
 *   "queryStringParameters": {
 *     parameters
 *   },
 *   "headers": {
 *     "accept": "text/html,application/xhtml+xml",
 *     "accept-language": "en-US,en;q=0.8",
 *     "content-type": "text/plain",
 *     "cookie": "cookies",
 *     "host": "lambda-846800462-us-east-2.elb.amazonaws.com",
 *     "user-agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_11_6)",
 *     "x-amzn-trace-id": "Root=1-5bdb40ca-556d8b0c50dc66f0511bf520",
 *     "x-forwarded-for": "72.21.198.66",
 *     "x-forwarded-port": "443",
 *     "x-forwarded-proto": "https"
 *   },
 *   "isBase64Encoded": false,
 *   "body": "request_body"
 * }
 * ```
 *
 * With multi-value headers and multi-value query string parameters:
 *
 * @example
 * ```json
 * {
 *   "requestContext": {
 *     "elb": {
 *       "targetGroupArn": "arn:aws:elasticloadbalancing:region:123456789012:targetgroup/my-target-group/6d0ecf831eec9f09"
 *     }
 *   },
 *   "httpMethod": "GET",
 *   "path": "/",
 *   "multiValueHeaders": {
 *     "Set-cookie": [
 *       "cookie-name=cookie-value;Domain=myweb.com;Secure;HttpOnly",
 *       "cookie-name=cookie-value;Expires=May 8, 2019"
 *     ],
 *     "Content-Type": [
 *       "application/json"
 *     ]
 *   },
 *   "isBase64Encoded": false,
 *   "body": "request_body"
 * }
 * ```
 *
 * @see {@link types.ALBEvent | ALBEvent}
 * @see {@link https://docs.aws.amazon.com/elasticloadbalancing/latest/application/lambda-functions.html}
 * @see {@link https://docs.aws.amazon.com/lambda/latest/dg/services-alb.html}
 */
declare const AlbSchema: z.ZodObject<{
    httpMethod: z.ZodString;
    path: z.ZodString;
    body: z.ZodString;
    isBase64Encoded: z.ZodBoolean;
    headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
    multiValueHeaders: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodArray<z.ZodString, "many">>>;
    queryStringParameters: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
    multiValueQueryStringParameters: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodArray<z.ZodString, "many">>>;
    requestContext: z.ZodObject<{
        elb: z.ZodObject<{
            targetGroupArn: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            targetGroupArn: string;
        }, {
            targetGroupArn: string;
        }>;
    }, "strip", z.ZodTypeAny, {
        elb: {
            targetGroupArn: string;
        };
    }, {
        elb: {
            targetGroupArn: string;
        };
    }>;
}, "strip", z.ZodTypeAny, {
    path: string;
    httpMethod: string;
    body: string;
    isBase64Encoded: boolean;
    requestContext: {
        elb: {
            targetGroupArn: string;
        };
    };
    headers?: Record<string, string> | undefined;
    multiValueHeaders?: Record<string, string[]> | undefined;
    queryStringParameters?: Record<string, string> | undefined;
    multiValueQueryStringParameters?: Record<string, string[]> | undefined;
}, {
    path: string;
    httpMethod: string;
    body: string;
    isBase64Encoded: boolean;
    requestContext: {
        elb: {
            targetGroupArn: string;
        };
    };
    headers?: Record<string, string> | undefined;
    multiValueHeaders?: Record<string, string[]> | undefined;
    queryStringParameters?: Record<string, string> | undefined;
    multiValueQueryStringParameters?: Record<string, string[]> | undefined;
}>;
/**
 * @deprecated Use `AlbSchema` instead, which handles both types of headers & querystring parameters.
 *
 * This schema will be removed in a future major release.
 */
declare const AlbMultiValueHeadersSchema: z.ZodObject<z.objectUtil.extendShape<{
    httpMethod: z.ZodString;
    path: z.ZodString;
    body: z.ZodString;
    isBase64Encoded: z.ZodBoolean;
    headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
    multiValueHeaders: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodArray<z.ZodString, "many">>>;
    queryStringParameters: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
    multiValueQueryStringParameters: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodArray<z.ZodString, "many">>>;
    requestContext: z.ZodObject<{
        elb: z.ZodObject<{
            targetGroupArn: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            targetGroupArn: string;
        }, {
            targetGroupArn: string;
        }>;
    }, "strip", z.ZodTypeAny, {
        elb: {
            targetGroupArn: string;
        };
    }, {
        elb: {
            targetGroupArn: string;
        };
    }>;
}, {
    multiValueHeaders: z.ZodRecord<z.ZodString, z.ZodArray<z.ZodString, "many">>;
    multiValueQueryStringParameters: z.ZodRecord<z.ZodString, z.ZodArray<z.ZodString, "many">>;
}>, "strip", z.ZodTypeAny, {
    path: string;
    httpMethod: string;
    body: string;
    isBase64Encoded: boolean;
    multiValueHeaders: Record<string, string[]>;
    multiValueQueryStringParameters: Record<string, string[]>;
    requestContext: {
        elb: {
            targetGroupArn: string;
        };
    };
    headers?: Record<string, string> | undefined;
    queryStringParameters?: Record<string, string> | undefined;
}, {
    path: string;
    httpMethod: string;
    body: string;
    isBase64Encoded: boolean;
    multiValueHeaders: Record<string, string[]>;
    multiValueQueryStringParameters: Record<string, string[]>;
    requestContext: {
        elb: {
            targetGroupArn: string;
        };
    };
    headers?: Record<string, string> | undefined;
    queryStringParameters?: Record<string, string> | undefined;
}>;
export { AlbSchema, AlbMultiValueHeadersSchema };
//# sourceMappingURL=alb.d.ts.map