import { z } from 'zod';
/**
 * A zod schema for API Gateway Proxy WebSocket events.
 *
 * @example
 * ```json
 * {
 *   "type": "REQUEST",
 *   "methodArn": "arn:aws:execute-api:us-east-1:123456789012:abcdef123/default/$connect",
 *   "headers": {
 *     "Connection": "upgrade",
 *     "content-length": "0",
 *     "HeaderAuth1": "headerValue1",
 *     "Host": "abcdef123.execute-api.us-east-1.amazonaws.com",
 *     "Sec-WebSocket-Extensions": "permessage-deflate; client_max_window_bits",
 *     "Sec-WebSocket-Key": "...",
 *     "Sec-WebSocket-Version": "13",
 *     "Upgrade": "websocket",
 *     "X-Amzn-Trace-Id": "..."
 *   },
 *   "multiValueHeaders": {
 *     "Connection": [ "upgrade" ],
 *     "content-length": [ "0" ],
 *     "HeaderAuth1": [ "headerValue1" ],
 *     "Host": [ "abcdef123.execute-api.us-east-1.amazonaws.com" ],
 *     "Sec-WebSocket-Extensions": [ "permessage-deflate; client_max_window_bits" ],
 *     "Sec-WebSocket-Key": [ "..." ],
 *     "Sec-WebSocket-Version": [ "13" ],
 *     "Upgrade": [ "websocket" ],
 *     "X-Amzn-Trace-Id": [ "..." ]
 *   },
 *   "queryStringParameters": {
 *     "QueryString1": "queryValue1"
 *   },
 *   "multiValueQueryStringParameters": {
 *     "QueryString1": [ "queryValue1" ]
 *   },
 *   "stageVariables": {},
 *   "requestContext": {
 *     "routeKey": "$connect",
 *     "eventType": "CONNECT",
 *     "extendedRequestId": "...",
 *     "requestTime": "19/Jan/2023:21:13:26 +0000",
 *     "messageDirection": "IN",
 *     "stage": "default",
 *     "connectedAt": 1674162806344,
 *     "requestTimeEpoch": 1674162806345,
 *     "identity": {
 *       "sourceIp": "..."
 *     },
 *     "requestId": "...",
 *     "domainName": "abcdef123.execute-api.us-east-1.amazonaws.com",
 *     "connectionId": "...",
 *     "apiId": "abcdef123"
 *   },
 *   "isBase64Encoded": false,
 *   "body": null
 * }
 * ```
 *
 * @see {@link https://docs.aws.amazon.com/apigateway/latest/developerguide/websocket-api-develop-integrations.html}
 */
export declare const APIGatewayProxyWebsocketEventSchema: z.ZodObject<{
    type: z.ZodString;
    methodArn: z.ZodString;
    headers: z.ZodRecord<z.ZodString, z.ZodString>;
    multiValueHeaders: z.ZodRecord<z.ZodString, z.ZodArray<z.ZodString, "many">>;
    queryStringParameters: z.ZodOptional<z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodString>>>;
    multiValueQueryStringParameters: z.ZodOptional<z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodArray<z.ZodString, "many">>>>;
    stageVariables: z.ZodOptional<z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodString>>>;
    requestContext: z.ZodObject<{
        routeKey: z.ZodString;
        eventType: z.ZodEnum<["CONNECT", "DISCONNECT", "MESSAGE"]>;
        extendedRequestId: z.ZodString;
        requestTime: z.ZodString;
        messageDirection: z.ZodEnum<["IN", "OUT"]>;
        stage: z.ZodString;
        connectedAt: z.ZodNumber;
        requestTimeEpoch: z.ZodNumber;
        identity: z.ZodObject<{
            sourceIp: z.ZodString;
            userAgent: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            sourceIp: string;
            userAgent?: string | undefined;
        }, {
            sourceIp: string;
            userAgent?: string | undefined;
        }>;
        requestId: z.ZodString;
        domainName: z.ZodString;
        connectionId: z.ZodString;
        apiId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        apiId: string;
        stage: string;
        identity: {
            sourceIp: string;
            userAgent?: string | undefined;
        };
        requestId: string;
        requestTime: string;
        requestTimeEpoch: number;
        domainName: string;
        extendedRequestId: string;
        connectedAt: number;
        connectionId: string;
        eventType: "CONNECT" | "MESSAGE" | "DISCONNECT";
        messageDirection: "IN" | "OUT";
        routeKey: string;
    }, {
        apiId: string;
        stage: string;
        identity: {
            sourceIp: string;
            userAgent?: string | undefined;
        };
        requestId: string;
        requestTime: string;
        requestTimeEpoch: number;
        domainName: string;
        extendedRequestId: string;
        connectedAt: number;
        connectionId: string;
        eventType: "CONNECT" | "MESSAGE" | "DISCONNECT";
        messageDirection: "IN" | "OUT";
        routeKey: string;
    }>;
    isBase64Encoded: z.ZodBoolean;
    body: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    type: string;
    isBase64Encoded: boolean;
    headers: Record<string, string>;
    multiValueHeaders: Record<string, string[]>;
    requestContext: {
        apiId: string;
        stage: string;
        identity: {
            sourceIp: string;
            userAgent?: string | undefined;
        };
        requestId: string;
        requestTime: string;
        requestTimeEpoch: number;
        domainName: string;
        extendedRequestId: string;
        connectedAt: number;
        connectionId: string;
        eventType: "CONNECT" | "MESSAGE" | "DISCONNECT";
        messageDirection: "IN" | "OUT";
        routeKey: string;
    };
    methodArn: string;
    body?: string | null | undefined;
    queryStringParameters?: Record<string, string> | null | undefined;
    multiValueQueryStringParameters?: Record<string, string[]> | null | undefined;
    stageVariables?: Record<string, string> | null | undefined;
}, {
    type: string;
    isBase64Encoded: boolean;
    headers: Record<string, string>;
    multiValueHeaders: Record<string, string[]>;
    requestContext: {
        apiId: string;
        stage: string;
        identity: {
            sourceIp: string;
            userAgent?: string | undefined;
        };
        requestId: string;
        requestTime: string;
        requestTimeEpoch: number;
        domainName: string;
        extendedRequestId: string;
        connectedAt: number;
        connectionId: string;
        eventType: "CONNECT" | "MESSAGE" | "DISCONNECT";
        messageDirection: "IN" | "OUT";
        routeKey: string;
    };
    methodArn: string;
    body?: string | null | undefined;
    queryStringParameters?: Record<string, string> | null | undefined;
    multiValueQueryStringParameters?: Record<string, string[]> | null | undefined;
    stageVariables?: Record<string, string> | null | undefined;
}>;
//# sourceMappingURL=api-gateway-websocket.d.ts.map