import { z } from 'zod';
/**
 * A zod schema for an API Gateway Event Request Context
 *
 * @see {@link https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-mapping-template-reference.html#context-variable-reference}
 */
declare const APIGatewayEventRequestContextSchema: z.ZodEffects<z.ZodObject<{
    accountId: z.ZodString;
    apiId: z.ZodString;
    deploymentId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    authorizer: z.ZodOptional<z.ZodNullable<z.ZodUnion<[z.ZodObject<{
        integrationLatency: z.ZodNumber;
        principalId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        integrationLatency: number;
        principalId: string;
    }, {
        integrationLatency: number;
        principalId: string;
    }>, z.ZodObject<{
        claims: z.ZodRecord<z.ZodString, z.ZodAny>;
        scopes: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    }, "strip", z.ZodTypeAny, {
        claims: Record<string, any>;
        scopes?: string[] | undefined;
    }, {
        claims: Record<string, any>;
        scopes?: string[] | undefined;
    }>]>>>;
    stage: z.ZodString;
    protocol: z.ZodString;
    identity: z.ZodObject<{
        accessKey: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        accountId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        apiKey: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        apiKeyId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        caller: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        cognitoAuthenticationProvider: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        cognitoAuthenticationType: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        cognitoIdentityId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        cognitoIdentityPoolId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        principalOrgId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        /**
         * When invoking the API Gateway REST API using the Test Invoke feature,
         * the sourceIp is hardcoded to `test-invoke-source-ip`. This is a stopgap
         * solution to allow customers to test their API and have successful parsing.
         *
         * See aws-powertools/powertools-lambda-python#1562 for more information.
         */
        sourceIp: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodLiteral<"test-invoke-source-ip">]>>;
        user: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        userAgent: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        userArn: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        clientCert: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            clientCertPem: z.ZodString;
            subjectDN: z.ZodString;
            issuerDN: z.ZodString;
            serialNumber: z.ZodString;
            validity: z.ZodObject<{
                notBefore: z.ZodString;
                notAfter: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                notBefore: string;
                notAfter: string;
            }, {
                notBefore: string;
                notAfter: string;
            }>;
        }, "strip", z.ZodTypeAny, {
            clientCertPem: string;
            subjectDN: string;
            issuerDN: string;
            serialNumber: string;
            validity: {
                notBefore: string;
                notAfter: string;
            };
        }, {
            clientCertPem: string;
            subjectDN: string;
            issuerDN: string;
            serialNumber: string;
            validity: {
                notBefore: string;
                notAfter: string;
            };
        }>>>;
    }, "strip", z.ZodTypeAny, {
        accessKey?: string | null | undefined;
        accountId?: string | null | undefined;
        apiKey?: string | null | undefined;
        apiKeyId?: string | null | undefined;
        caller?: string | null | undefined;
        cognitoAuthenticationProvider?: string | null | undefined;
        cognitoAuthenticationType?: string | null | undefined;
        cognitoIdentityId?: string | null | undefined;
        cognitoIdentityPoolId?: string | null | undefined;
        principalOrgId?: string | null | undefined;
        sourceIp?: string | undefined;
        user?: string | null | undefined;
        userAgent?: string | null | undefined;
        userArn?: string | null | undefined;
        clientCert?: {
            clientCertPem: string;
            subjectDN: string;
            issuerDN: string;
            serialNumber: string;
            validity: {
                notBefore: string;
                notAfter: string;
            };
        } | null | undefined;
    }, {
        accessKey?: string | null | undefined;
        accountId?: string | null | undefined;
        apiKey?: string | null | undefined;
        apiKeyId?: string | null | undefined;
        caller?: string | null | undefined;
        cognitoAuthenticationProvider?: string | null | undefined;
        cognitoAuthenticationType?: string | null | undefined;
        cognitoIdentityId?: string | null | undefined;
        cognitoIdentityPoolId?: string | null | undefined;
        principalOrgId?: string | null | undefined;
        sourceIp?: string | undefined;
        user?: string | null | undefined;
        userAgent?: string | null | undefined;
        userArn?: string | null | undefined;
        clientCert?: {
            clientCertPem: string;
            subjectDN: string;
            issuerDN: string;
            serialNumber: string;
            validity: {
                notBefore: string;
                notAfter: string;
            };
        } | null | undefined;
    }>;
    requestId: z.ZodString;
    requestTime: z.ZodString;
    requestTimeEpoch: z.ZodNumber;
    resourceId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    resourcePath: z.ZodString;
    domainName: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    domainPrefix: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    extendedRequestId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    httpMethod: z.ZodEnum<["GET", "POST", "PUT", "PATCH", "DELETE", "HEAD", "OPTIONS"]>;
    path: z.ZodString;
    connectedAt: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
    connectionId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    eventType: z.ZodOptional<z.ZodNullable<z.ZodEnum<["CONNECT", "MESSAGE", "DISCONNECT"]>>>;
    messageDirection: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    messageId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    routeKey: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    operationName: z.ZodOptional<z.ZodNullable<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    path: string;
    httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
    accountId: string;
    apiId: string;
    stage: string;
    protocol: string;
    identity: {
        accessKey?: string | null | undefined;
        accountId?: string | null | undefined;
        apiKey?: string | null | undefined;
        apiKeyId?: string | null | undefined;
        caller?: string | null | undefined;
        cognitoAuthenticationProvider?: string | null | undefined;
        cognitoAuthenticationType?: string | null | undefined;
        cognitoIdentityId?: string | null | undefined;
        cognitoIdentityPoolId?: string | null | undefined;
        principalOrgId?: string | null | undefined;
        sourceIp?: string | undefined;
        user?: string | null | undefined;
        userAgent?: string | null | undefined;
        userArn?: string | null | undefined;
        clientCert?: {
            clientCertPem: string;
            subjectDN: string;
            issuerDN: string;
            serialNumber: string;
            validity: {
                notBefore: string;
                notAfter: string;
            };
        } | null | undefined;
    };
    requestId: string;
    requestTime: string;
    requestTimeEpoch: number;
    resourcePath: string;
    deploymentId?: string | null | undefined;
    authorizer?: {
        integrationLatency: number;
        principalId: string;
    } | {
        claims: Record<string, any>;
        scopes?: string[] | undefined;
    } | null | undefined;
    resourceId?: string | null | undefined;
    domainName?: string | null | undefined;
    domainPrefix?: string | null | undefined;
    extendedRequestId?: string | null | undefined;
    connectedAt?: number | null | undefined;
    connectionId?: string | null | undefined;
    eventType?: "CONNECT" | "MESSAGE" | "DISCONNECT" | null | undefined;
    messageDirection?: string | null | undefined;
    messageId?: string | null | undefined;
    routeKey?: string | null | undefined;
    operationName?: string | null | undefined;
}, {
    path: string;
    httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
    accountId: string;
    apiId: string;
    stage: string;
    protocol: string;
    identity: {
        accessKey?: string | null | undefined;
        accountId?: string | null | undefined;
        apiKey?: string | null | undefined;
        apiKeyId?: string | null | undefined;
        caller?: string | null | undefined;
        cognitoAuthenticationProvider?: string | null | undefined;
        cognitoAuthenticationType?: string | null | undefined;
        cognitoIdentityId?: string | null | undefined;
        cognitoIdentityPoolId?: string | null | undefined;
        principalOrgId?: string | null | undefined;
        sourceIp?: string | undefined;
        user?: string | null | undefined;
        userAgent?: string | null | undefined;
        userArn?: string | null | undefined;
        clientCert?: {
            clientCertPem: string;
            subjectDN: string;
            issuerDN: string;
            serialNumber: string;
            validity: {
                notBefore: string;
                notAfter: string;
            };
        } | null | undefined;
    };
    requestId: string;
    requestTime: string;
    requestTimeEpoch: number;
    resourcePath: string;
    deploymentId?: string | null | undefined;
    authorizer?: {
        integrationLatency: number;
        principalId: string;
    } | {
        claims: Record<string, any>;
        scopes?: string[] | undefined;
    } | null | undefined;
    resourceId?: string | null | undefined;
    domainName?: string | null | undefined;
    domainPrefix?: string | null | undefined;
    extendedRequestId?: string | null | undefined;
    connectedAt?: number | null | undefined;
    connectionId?: string | null | undefined;
    eventType?: "CONNECT" | "MESSAGE" | "DISCONNECT" | null | undefined;
    messageDirection?: string | null | undefined;
    messageId?: string | null | undefined;
    routeKey?: string | null | undefined;
    operationName?: string | null | undefined;
}>, {
    path: string;
    httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
    accountId: string;
    apiId: string;
    stage: string;
    protocol: string;
    identity: {
        accessKey?: string | null | undefined;
        accountId?: string | null | undefined;
        apiKey?: string | null | undefined;
        apiKeyId?: string | null | undefined;
        caller?: string | null | undefined;
        cognitoAuthenticationProvider?: string | null | undefined;
        cognitoAuthenticationType?: string | null | undefined;
        cognitoIdentityId?: string | null | undefined;
        cognitoIdentityPoolId?: string | null | undefined;
        principalOrgId?: string | null | undefined;
        sourceIp?: string | undefined;
        user?: string | null | undefined;
        userAgent?: string | null | undefined;
        userArn?: string | null | undefined;
        clientCert?: {
            clientCertPem: string;
            subjectDN: string;
            issuerDN: string;
            serialNumber: string;
            validity: {
                notBefore: string;
                notAfter: string;
            };
        } | null | undefined;
    };
    requestId: string;
    requestTime: string;
    requestTimeEpoch: number;
    resourcePath: string;
    deploymentId?: string | null | undefined;
    authorizer?: {
        integrationLatency: number;
        principalId: string;
    } | {
        claims: Record<string, any>;
        scopes?: string[] | undefined;
    } | null | undefined;
    resourceId?: string | null | undefined;
    domainName?: string | null | undefined;
    domainPrefix?: string | null | undefined;
    extendedRequestId?: string | null | undefined;
    connectedAt?: number | null | undefined;
    connectionId?: string | null | undefined;
    eventType?: "CONNECT" | "MESSAGE" | "DISCONNECT" | null | undefined;
    messageDirection?: string | null | undefined;
    messageId?: string | null | undefined;
    routeKey?: string | null | undefined;
    operationName?: string | null | undefined;
}, {
    path: string;
    httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
    accountId: string;
    apiId: string;
    stage: string;
    protocol: string;
    identity: {
        accessKey?: string | null | undefined;
        accountId?: string | null | undefined;
        apiKey?: string | null | undefined;
        apiKeyId?: string | null | undefined;
        caller?: string | null | undefined;
        cognitoAuthenticationProvider?: string | null | undefined;
        cognitoAuthenticationType?: string | null | undefined;
        cognitoIdentityId?: string | null | undefined;
        cognitoIdentityPoolId?: string | null | undefined;
        principalOrgId?: string | null | undefined;
        sourceIp?: string | undefined;
        user?: string | null | undefined;
        userAgent?: string | null | undefined;
        userArn?: string | null | undefined;
        clientCert?: {
            clientCertPem: string;
            subjectDN: string;
            issuerDN: string;
            serialNumber: string;
            validity: {
                notBefore: string;
                notAfter: string;
            };
        } | null | undefined;
    };
    requestId: string;
    requestTime: string;
    requestTimeEpoch: number;
    resourcePath: string;
    deploymentId?: string | null | undefined;
    authorizer?: {
        integrationLatency: number;
        principalId: string;
    } | {
        claims: Record<string, any>;
        scopes?: string[] | undefined;
    } | null | undefined;
    resourceId?: string | null | undefined;
    domainName?: string | null | undefined;
    domainPrefix?: string | null | undefined;
    extendedRequestId?: string | null | undefined;
    connectedAt?: number | null | undefined;
    connectionId?: string | null | undefined;
    eventType?: "CONNECT" | "MESSAGE" | "DISCONNECT" | null | undefined;
    messageDirection?: string | null | undefined;
    messageId?: string | null | undefined;
    routeKey?: string | null | undefined;
    operationName?: string | null | undefined;
}>;
/**
 * A zod schema for an API Gateway Proxy event
 *
 * @example
 * ```json
 * {
 *   "type": "REQUEST",
 *   "methodArn": "arn:aws:execute-api:us-east-1:123456789012:abcdef123/test/GET/request",
 *   "resource": "/request",
 *   "path": "/request",
 *   "httpMethod": "GET",
 *   "headers": {
 *     "X-AMZ-Date": "20170718T062915Z",
 *     "Accept": "application/json",
 *     "HeaderAuth1": "headerValue1"
 *   },
 *   "queryStringParameters": {
 *     "QueryString1": "queryValue1"
 *   },
 *   "pathParameters": {},
 *   "stageVariables": null,
 *   "requestContext": {
 *     "path": "/request",
 *     "accountId": "123456789012",
 *     "resourceId": "05c7jb",
 *     "stage": "test",
 *     "requestId": "...",
 *     "identity": {
 *       "cognitoIdentityPoolId": null,
 *       "accountId": null,
 *       "cognitoIdentityId": null,
 *       "caller": null,
 *       "sourceIp": "192.168.1.1",
 *       "principalOrgId": null,
 *       "accessKey": null,
 *       "cognitoAuthenticationType": null,
 *       "cognitoAuthenticationProvider": null,
 *       "userArn": null,
 *       "userAgent": "HTTPie/3.2.2",
 *       "user": null
 *     }
 *   },
 *   "resourcePath": "/request",
 *   "httpMethod": "GET",
 *   "apiId": "abcdef123"
 * }
 * ```
 * @see {@link types.APIGatewayProxyEvent | APIGatewayProxyEvent}
 *
 * @see {@link https://docs.aws.amazon.com/apigateway/latest/developerguide/set-up-lambda-proxy-integrations.html}
 */
declare const APIGatewayProxyEventSchema: z.ZodObject<{
    resource: z.ZodString;
    path: z.ZodString;
    httpMethod: z.ZodEnum<["GET", "POST", "PUT", "PATCH", "DELETE", "HEAD", "OPTIONS"]>;
    headers: z.ZodOptional<z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodString>>>;
    multiValueHeaders: z.ZodOptional<z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodArray<z.ZodString, "many">>>>;
    queryStringParameters: z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodString>>;
    multiValueQueryStringParameters: z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodArray<z.ZodString, "many">>>;
    pathParameters: z.ZodOptional<z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodString>>>;
    stageVariables: z.ZodOptional<z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodString>>>;
    requestContext: z.ZodEffects<z.ZodObject<{
        accountId: z.ZodString;
        apiId: z.ZodString;
        deploymentId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        authorizer: z.ZodOptional<z.ZodNullable<z.ZodUnion<[z.ZodObject<{
            integrationLatency: z.ZodNumber;
            principalId: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            integrationLatency: number;
            principalId: string;
        }, {
            integrationLatency: number;
            principalId: string;
        }>, z.ZodObject<{
            claims: z.ZodRecord<z.ZodString, z.ZodAny>;
            scopes: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        }, "strip", z.ZodTypeAny, {
            claims: Record<string, any>;
            scopes?: string[] | undefined;
        }, {
            claims: Record<string, any>;
            scopes?: string[] | undefined;
        }>]>>>;
        stage: z.ZodString;
        protocol: z.ZodString;
        identity: z.ZodObject<{
            accessKey: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            accountId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            apiKey: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            apiKeyId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            caller: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            cognitoAuthenticationProvider: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            cognitoAuthenticationType: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            cognitoIdentityId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            cognitoIdentityPoolId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            principalOrgId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            /**
             * When invoking the API Gateway REST API using the Test Invoke feature,
             * the sourceIp is hardcoded to `test-invoke-source-ip`. This is a stopgap
             * solution to allow customers to test their API and have successful parsing.
             *
             * See aws-powertools/powertools-lambda-python#1562 for more information.
             */
            sourceIp: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodLiteral<"test-invoke-source-ip">]>>;
            user: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            userAgent: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            userArn: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            clientCert: z.ZodOptional<z.ZodNullable<z.ZodObject<{
                clientCertPem: z.ZodString;
                subjectDN: z.ZodString;
                issuerDN: z.ZodString;
                serialNumber: z.ZodString;
                validity: z.ZodObject<{
                    notBefore: z.ZodString;
                    notAfter: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    notBefore: string;
                    notAfter: string;
                }, {
                    notBefore: string;
                    notAfter: string;
                }>;
            }, "strip", z.ZodTypeAny, {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            }, {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            }>>>;
        }, "strip", z.ZodTypeAny, {
            accessKey?: string | null | undefined;
            accountId?: string | null | undefined;
            apiKey?: string | null | undefined;
            apiKeyId?: string | null | undefined;
            caller?: string | null | undefined;
            cognitoAuthenticationProvider?: string | null | undefined;
            cognitoAuthenticationType?: string | null | undefined;
            cognitoIdentityId?: string | null | undefined;
            cognitoIdentityPoolId?: string | null | undefined;
            principalOrgId?: string | null | undefined;
            sourceIp?: string | undefined;
            user?: string | null | undefined;
            userAgent?: string | null | undefined;
            userArn?: string | null | undefined;
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | null | undefined;
        }, {
            accessKey?: string | null | undefined;
            accountId?: string | null | undefined;
            apiKey?: string | null | undefined;
            apiKeyId?: string | null | undefined;
            caller?: string | null | undefined;
            cognitoAuthenticationProvider?: string | null | undefined;
            cognitoAuthenticationType?: string | null | undefined;
            cognitoIdentityId?: string | null | undefined;
            cognitoIdentityPoolId?: string | null | undefined;
            principalOrgId?: string | null | undefined;
            sourceIp?: string | undefined;
            user?: string | null | undefined;
            userAgent?: string | null | undefined;
            userArn?: string | null | undefined;
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | null | undefined;
        }>;
        requestId: z.ZodString;
        requestTime: z.ZodString;
        requestTimeEpoch: z.ZodNumber;
        resourceId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        resourcePath: z.ZodString;
        domainName: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        domainPrefix: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        extendedRequestId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        httpMethod: z.ZodEnum<["GET", "POST", "PUT", "PATCH", "DELETE", "HEAD", "OPTIONS"]>;
        path: z.ZodString;
        connectedAt: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
        connectionId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        eventType: z.ZodOptional<z.ZodNullable<z.ZodEnum<["CONNECT", "MESSAGE", "DISCONNECT"]>>>;
        messageDirection: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        messageId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        routeKey: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        operationName: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        path: string;
        httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        accountId: string;
        apiId: string;
        stage: string;
        protocol: string;
        identity: {
            accessKey?: string | null | undefined;
            accountId?: string | null | undefined;
            apiKey?: string | null | undefined;
            apiKeyId?: string | null | undefined;
            caller?: string | null | undefined;
            cognitoAuthenticationProvider?: string | null | undefined;
            cognitoAuthenticationType?: string | null | undefined;
            cognitoIdentityId?: string | null | undefined;
            cognitoIdentityPoolId?: string | null | undefined;
            principalOrgId?: string | null | undefined;
            sourceIp?: string | undefined;
            user?: string | null | undefined;
            userAgent?: string | null | undefined;
            userArn?: string | null | undefined;
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | null | undefined;
        };
        requestId: string;
        requestTime: string;
        requestTimeEpoch: number;
        resourcePath: string;
        deploymentId?: string | null | undefined;
        authorizer?: {
            integrationLatency: number;
            principalId: string;
        } | {
            claims: Record<string, any>;
            scopes?: string[] | undefined;
        } | null | undefined;
        resourceId?: string | null | undefined;
        domainName?: string | null | undefined;
        domainPrefix?: string | null | undefined;
        extendedRequestId?: string | null | undefined;
        connectedAt?: number | null | undefined;
        connectionId?: string | null | undefined;
        eventType?: "CONNECT" | "MESSAGE" | "DISCONNECT" | null | undefined;
        messageDirection?: string | null | undefined;
        messageId?: string | null | undefined;
        routeKey?: string | null | undefined;
        operationName?: string | null | undefined;
    }, {
        path: string;
        httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        accountId: string;
        apiId: string;
        stage: string;
        protocol: string;
        identity: {
            accessKey?: string | null | undefined;
            accountId?: string | null | undefined;
            apiKey?: string | null | undefined;
            apiKeyId?: string | null | undefined;
            caller?: string | null | undefined;
            cognitoAuthenticationProvider?: string | null | undefined;
            cognitoAuthenticationType?: string | null | undefined;
            cognitoIdentityId?: string | null | undefined;
            cognitoIdentityPoolId?: string | null | undefined;
            principalOrgId?: string | null | undefined;
            sourceIp?: string | undefined;
            user?: string | null | undefined;
            userAgent?: string | null | undefined;
            userArn?: string | null | undefined;
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | null | undefined;
        };
        requestId: string;
        requestTime: string;
        requestTimeEpoch: number;
        resourcePath: string;
        deploymentId?: string | null | undefined;
        authorizer?: {
            integrationLatency: number;
            principalId: string;
        } | {
            claims: Record<string, any>;
            scopes?: string[] | undefined;
        } | null | undefined;
        resourceId?: string | null | undefined;
        domainName?: string | null | undefined;
        domainPrefix?: string | null | undefined;
        extendedRequestId?: string | null | undefined;
        connectedAt?: number | null | undefined;
        connectionId?: string | null | undefined;
        eventType?: "CONNECT" | "MESSAGE" | "DISCONNECT" | null | undefined;
        messageDirection?: string | null | undefined;
        messageId?: string | null | undefined;
        routeKey?: string | null | undefined;
        operationName?: string | null | undefined;
    }>, {
        path: string;
        httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        accountId: string;
        apiId: string;
        stage: string;
        protocol: string;
        identity: {
            accessKey?: string | null | undefined;
            accountId?: string | null | undefined;
            apiKey?: string | null | undefined;
            apiKeyId?: string | null | undefined;
            caller?: string | null | undefined;
            cognitoAuthenticationProvider?: string | null | undefined;
            cognitoAuthenticationType?: string | null | undefined;
            cognitoIdentityId?: string | null | undefined;
            cognitoIdentityPoolId?: string | null | undefined;
            principalOrgId?: string | null | undefined;
            sourceIp?: string | undefined;
            user?: string | null | undefined;
            userAgent?: string | null | undefined;
            userArn?: string | null | undefined;
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | null | undefined;
        };
        requestId: string;
        requestTime: string;
        requestTimeEpoch: number;
        resourcePath: string;
        deploymentId?: string | null | undefined;
        authorizer?: {
            integrationLatency: number;
            principalId: string;
        } | {
            claims: Record<string, any>;
            scopes?: string[] | undefined;
        } | null | undefined;
        resourceId?: string | null | undefined;
        domainName?: string | null | undefined;
        domainPrefix?: string | null | undefined;
        extendedRequestId?: string | null | undefined;
        connectedAt?: number | null | undefined;
        connectionId?: string | null | undefined;
        eventType?: "CONNECT" | "MESSAGE" | "DISCONNECT" | null | undefined;
        messageDirection?: string | null | undefined;
        messageId?: string | null | undefined;
        routeKey?: string | null | undefined;
        operationName?: string | null | undefined;
    }, {
        path: string;
        httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        accountId: string;
        apiId: string;
        stage: string;
        protocol: string;
        identity: {
            accessKey?: string | null | undefined;
            accountId?: string | null | undefined;
            apiKey?: string | null | undefined;
            apiKeyId?: string | null | undefined;
            caller?: string | null | undefined;
            cognitoAuthenticationProvider?: string | null | undefined;
            cognitoAuthenticationType?: string | null | undefined;
            cognitoIdentityId?: string | null | undefined;
            cognitoIdentityPoolId?: string | null | undefined;
            principalOrgId?: string | null | undefined;
            sourceIp?: string | undefined;
            user?: string | null | undefined;
            userAgent?: string | null | undefined;
            userArn?: string | null | undefined;
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | null | undefined;
        };
        requestId: string;
        requestTime: string;
        requestTimeEpoch: number;
        resourcePath: string;
        deploymentId?: string | null | undefined;
        authorizer?: {
            integrationLatency: number;
            principalId: string;
        } | {
            claims: Record<string, any>;
            scopes?: string[] | undefined;
        } | null | undefined;
        resourceId?: string | null | undefined;
        domainName?: string | null | undefined;
        domainPrefix?: string | null | undefined;
        extendedRequestId?: string | null | undefined;
        connectedAt?: number | null | undefined;
        connectionId?: string | null | undefined;
        eventType?: "CONNECT" | "MESSAGE" | "DISCONNECT" | null | undefined;
        messageDirection?: string | null | undefined;
        messageId?: string | null | undefined;
        routeKey?: string | null | undefined;
        operationName?: string | null | undefined;
    }>;
    body: z.ZodNullable<z.ZodString>;
    isBase64Encoded: z.ZodBoolean;
}, "strip", z.ZodTypeAny, {
    path: string;
    httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
    body: string | null;
    isBase64Encoded: boolean;
    queryStringParameters: Record<string, string> | null;
    multiValueQueryStringParameters: Record<string, string[]> | null;
    requestContext: {
        path: string;
        httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        accountId: string;
        apiId: string;
        stage: string;
        protocol: string;
        identity: {
            accessKey?: string | null | undefined;
            accountId?: string | null | undefined;
            apiKey?: string | null | undefined;
            apiKeyId?: string | null | undefined;
            caller?: string | null | undefined;
            cognitoAuthenticationProvider?: string | null | undefined;
            cognitoAuthenticationType?: string | null | undefined;
            cognitoIdentityId?: string | null | undefined;
            cognitoIdentityPoolId?: string | null | undefined;
            principalOrgId?: string | null | undefined;
            sourceIp?: string | undefined;
            user?: string | null | undefined;
            userAgent?: string | null | undefined;
            userArn?: string | null | undefined;
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | null | undefined;
        };
        requestId: string;
        requestTime: string;
        requestTimeEpoch: number;
        resourcePath: string;
        deploymentId?: string | null | undefined;
        authorizer?: {
            integrationLatency: number;
            principalId: string;
        } | {
            claims: Record<string, any>;
            scopes?: string[] | undefined;
        } | null | undefined;
        resourceId?: string | null | undefined;
        domainName?: string | null | undefined;
        domainPrefix?: string | null | undefined;
        extendedRequestId?: string | null | undefined;
        connectedAt?: number | null | undefined;
        connectionId?: string | null | undefined;
        eventType?: "CONNECT" | "MESSAGE" | "DISCONNECT" | null | undefined;
        messageDirection?: string | null | undefined;
        messageId?: string | null | undefined;
        routeKey?: string | null | undefined;
        operationName?: string | null | undefined;
    };
    resource: string;
    headers?: Record<string, string> | null | undefined;
    multiValueHeaders?: Record<string, string[]> | null | undefined;
    pathParameters?: Record<string, string> | null | undefined;
    stageVariables?: Record<string, string> | null | undefined;
}, {
    path: string;
    httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
    body: string | null;
    isBase64Encoded: boolean;
    queryStringParameters: Record<string, string> | null;
    multiValueQueryStringParameters: Record<string, string[]> | null;
    requestContext: {
        path: string;
        httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        accountId: string;
        apiId: string;
        stage: string;
        protocol: string;
        identity: {
            accessKey?: string | null | undefined;
            accountId?: string | null | undefined;
            apiKey?: string | null | undefined;
            apiKeyId?: string | null | undefined;
            caller?: string | null | undefined;
            cognitoAuthenticationProvider?: string | null | undefined;
            cognitoAuthenticationType?: string | null | undefined;
            cognitoIdentityId?: string | null | undefined;
            cognitoIdentityPoolId?: string | null | undefined;
            principalOrgId?: string | null | undefined;
            sourceIp?: string | undefined;
            user?: string | null | undefined;
            userAgent?: string | null | undefined;
            userArn?: string | null | undefined;
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | null | undefined;
        };
        requestId: string;
        requestTime: string;
        requestTimeEpoch: number;
        resourcePath: string;
        deploymentId?: string | null | undefined;
        authorizer?: {
            integrationLatency: number;
            principalId: string;
        } | {
            claims: Record<string, any>;
            scopes?: string[] | undefined;
        } | null | undefined;
        resourceId?: string | null | undefined;
        domainName?: string | null | undefined;
        domainPrefix?: string | null | undefined;
        extendedRequestId?: string | null | undefined;
        connectedAt?: number | null | undefined;
        connectionId?: string | null | undefined;
        eventType?: "CONNECT" | "MESSAGE" | "DISCONNECT" | null | undefined;
        messageDirection?: string | null | undefined;
        messageId?: string | null | undefined;
        routeKey?: string | null | undefined;
        operationName?: string | null | undefined;
    };
    resource: string;
    headers?: Record<string, string> | null | undefined;
    multiValueHeaders?: Record<string, string[]> | null | undefined;
    pathParameters?: Record<string, string> | null | undefined;
    stageVariables?: Record<string, string> | null | undefined;
}>;
/**
 * A zod schema for an API Gateway Request Authorizer event
 *
 * @example
 * ```json
 * {
 *   "type": "REQUEST",
 *   "methodArn": "arn:aws:execute-api:us-west-2:123456789012:ymy8tbxw7b/prod/GET/",
 *   "resource": "/{proxy+}",
 *   "path": "/hello/world",
 *   "httpMethod": "GET",
 *   "headers": {
 *     "X-AMZ-Date": "20170718T062915Z",
 *     "Accept": "application/json",
 *     "HeaderAuth1": "headerValue1"
 *   },
 *   "multiValueHeaders": {
 *     "X-AMZ-Date": ["20170718T062915Z"],
 *     "Accept": ["application/json"],
 *     "HeaderAuth1": ["headerValue1"]
 *   },
 *   "queryStringParameters": {},
 *   "multiValueQueryStringParameters": {},
 *   "pathParameters": {},
 *   "stageVariables": {},
 *   "requestContext": {
 *     "path": "/request",
 *     "accountId": "123456789012",
 *     "resourceId": "05c7jb",
 *     "stage": "test",
 *     "requestId": "...",
 *     "identity": {
 *       "cognitoIdentityPoolId": null,
 *       "accountId": null,
 *       "cognitoIdentityId": null,
 *       "caller": null,
 *       "sourceIp": "192.168.1.1",
 *       "principalOrgId": null,
 *       "accessKey": null,
 *       "cognitoAuthenticationType": null,
 *       "cognitoAuthenticationProvider": null,
 *       "userArn": null,
 *       "userAgent": "HTTPie/3.2.2",
 *       "user": null
 *     }
 *   },
 *   "domainName": "id.execute-api.us-west-2.amazonaws.com",
 *   "deploymentId": "lle82z",
 *   "apiId": "ymy8tbxw7b"
 * }
 * ```
 *
 * @see {@link https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-lambda-authorizer-input.html#w76aac15b9c21c25c21b5}
 */
declare const APIGatewayRequestAuthorizerEventSchema: z.ZodObject<{
    type: z.ZodLiteral<"REQUEST">;
    methodArn: z.ZodString;
    resource: z.ZodString;
    path: z.ZodString;
    httpMethod: z.ZodEnum<["GET", "POST", "PUT", "PATCH", "DELETE", "HEAD", "OPTIONS"]>;
    headers: z.ZodRecord<z.ZodString, z.ZodString>;
    multiValueHeaders: z.ZodRecord<z.ZodString, z.ZodArray<z.ZodString, "many">>;
    queryStringParameters: z.ZodRecord<z.ZodString, z.ZodString>;
    multiValueQueryStringParameters: z.ZodRecord<z.ZodString, z.ZodArray<z.ZodString, "many">>;
    pathParameters: z.ZodRecord<z.ZodString, z.ZodString>;
    stageVariables: z.ZodRecord<z.ZodString, z.ZodString>;
    requestContext: z.ZodEffects<z.ZodObject<{
        accountId: z.ZodString;
        apiId: z.ZodString;
        deploymentId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        authorizer: z.ZodOptional<z.ZodNullable<z.ZodUnion<[z.ZodObject<{
            integrationLatency: z.ZodNumber;
            principalId: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            integrationLatency: number;
            principalId: string;
        }, {
            integrationLatency: number;
            principalId: string;
        }>, z.ZodObject<{
            claims: z.ZodRecord<z.ZodString, z.ZodAny>;
            scopes: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        }, "strip", z.ZodTypeAny, {
            claims: Record<string, any>;
            scopes?: string[] | undefined;
        }, {
            claims: Record<string, any>;
            scopes?: string[] | undefined;
        }>]>>>;
        stage: z.ZodString;
        protocol: z.ZodString;
        identity: z.ZodObject<{
            accessKey: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            accountId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            apiKey: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            apiKeyId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            caller: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            cognitoAuthenticationProvider: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            cognitoAuthenticationType: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            cognitoIdentityId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            cognitoIdentityPoolId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            principalOrgId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            /**
             * When invoking the API Gateway REST API using the Test Invoke feature,
             * the sourceIp is hardcoded to `test-invoke-source-ip`. This is a stopgap
             * solution to allow customers to test their API and have successful parsing.
             *
             * See aws-powertools/powertools-lambda-python#1562 for more information.
             */
            sourceIp: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodLiteral<"test-invoke-source-ip">]>>;
            user: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            userAgent: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            userArn: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            clientCert: z.ZodOptional<z.ZodNullable<z.ZodObject<{
                clientCertPem: z.ZodString;
                subjectDN: z.ZodString;
                issuerDN: z.ZodString;
                serialNumber: z.ZodString;
                validity: z.ZodObject<{
                    notBefore: z.ZodString;
                    notAfter: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    notBefore: string;
                    notAfter: string;
                }, {
                    notBefore: string;
                    notAfter: string;
                }>;
            }, "strip", z.ZodTypeAny, {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            }, {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            }>>>;
        }, "strip", z.ZodTypeAny, {
            accessKey?: string | null | undefined;
            accountId?: string | null | undefined;
            apiKey?: string | null | undefined;
            apiKeyId?: string | null | undefined;
            caller?: string | null | undefined;
            cognitoAuthenticationProvider?: string | null | undefined;
            cognitoAuthenticationType?: string | null | undefined;
            cognitoIdentityId?: string | null | undefined;
            cognitoIdentityPoolId?: string | null | undefined;
            principalOrgId?: string | null | undefined;
            sourceIp?: string | undefined;
            user?: string | null | undefined;
            userAgent?: string | null | undefined;
            userArn?: string | null | undefined;
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | null | undefined;
        }, {
            accessKey?: string | null | undefined;
            accountId?: string | null | undefined;
            apiKey?: string | null | undefined;
            apiKeyId?: string | null | undefined;
            caller?: string | null | undefined;
            cognitoAuthenticationProvider?: string | null | undefined;
            cognitoAuthenticationType?: string | null | undefined;
            cognitoIdentityId?: string | null | undefined;
            cognitoIdentityPoolId?: string | null | undefined;
            principalOrgId?: string | null | undefined;
            sourceIp?: string | undefined;
            user?: string | null | undefined;
            userAgent?: string | null | undefined;
            userArn?: string | null | undefined;
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | null | undefined;
        }>;
        requestId: z.ZodString;
        requestTime: z.ZodString;
        requestTimeEpoch: z.ZodNumber;
        resourceId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        resourcePath: z.ZodString;
        domainName: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        domainPrefix: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        extendedRequestId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        httpMethod: z.ZodEnum<["GET", "POST", "PUT", "PATCH", "DELETE", "HEAD", "OPTIONS"]>;
        path: z.ZodString;
        connectedAt: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
        connectionId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        eventType: z.ZodOptional<z.ZodNullable<z.ZodEnum<["CONNECT", "MESSAGE", "DISCONNECT"]>>>;
        messageDirection: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        messageId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        routeKey: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        operationName: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        path: string;
        httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        accountId: string;
        apiId: string;
        stage: string;
        protocol: string;
        identity: {
            accessKey?: string | null | undefined;
            accountId?: string | null | undefined;
            apiKey?: string | null | undefined;
            apiKeyId?: string | null | undefined;
            caller?: string | null | undefined;
            cognitoAuthenticationProvider?: string | null | undefined;
            cognitoAuthenticationType?: string | null | undefined;
            cognitoIdentityId?: string | null | undefined;
            cognitoIdentityPoolId?: string | null | undefined;
            principalOrgId?: string | null | undefined;
            sourceIp?: string | undefined;
            user?: string | null | undefined;
            userAgent?: string | null | undefined;
            userArn?: string | null | undefined;
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | null | undefined;
        };
        requestId: string;
        requestTime: string;
        requestTimeEpoch: number;
        resourcePath: string;
        deploymentId?: string | null | undefined;
        authorizer?: {
            integrationLatency: number;
            principalId: string;
        } | {
            claims: Record<string, any>;
            scopes?: string[] | undefined;
        } | null | undefined;
        resourceId?: string | null | undefined;
        domainName?: string | null | undefined;
        domainPrefix?: string | null | undefined;
        extendedRequestId?: string | null | undefined;
        connectedAt?: number | null | undefined;
        connectionId?: string | null | undefined;
        eventType?: "CONNECT" | "MESSAGE" | "DISCONNECT" | null | undefined;
        messageDirection?: string | null | undefined;
        messageId?: string | null | undefined;
        routeKey?: string | null | undefined;
        operationName?: string | null | undefined;
    }, {
        path: string;
        httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        accountId: string;
        apiId: string;
        stage: string;
        protocol: string;
        identity: {
            accessKey?: string | null | undefined;
            accountId?: string | null | undefined;
            apiKey?: string | null | undefined;
            apiKeyId?: string | null | undefined;
            caller?: string | null | undefined;
            cognitoAuthenticationProvider?: string | null | undefined;
            cognitoAuthenticationType?: string | null | undefined;
            cognitoIdentityId?: string | null | undefined;
            cognitoIdentityPoolId?: string | null | undefined;
            principalOrgId?: string | null | undefined;
            sourceIp?: string | undefined;
            user?: string | null | undefined;
            userAgent?: string | null | undefined;
            userArn?: string | null | undefined;
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | null | undefined;
        };
        requestId: string;
        requestTime: string;
        requestTimeEpoch: number;
        resourcePath: string;
        deploymentId?: string | null | undefined;
        authorizer?: {
            integrationLatency: number;
            principalId: string;
        } | {
            claims: Record<string, any>;
            scopes?: string[] | undefined;
        } | null | undefined;
        resourceId?: string | null | undefined;
        domainName?: string | null | undefined;
        domainPrefix?: string | null | undefined;
        extendedRequestId?: string | null | undefined;
        connectedAt?: number | null | undefined;
        connectionId?: string | null | undefined;
        eventType?: "CONNECT" | "MESSAGE" | "DISCONNECT" | null | undefined;
        messageDirection?: string | null | undefined;
        messageId?: string | null | undefined;
        routeKey?: string | null | undefined;
        operationName?: string | null | undefined;
    }>, {
        path: string;
        httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        accountId: string;
        apiId: string;
        stage: string;
        protocol: string;
        identity: {
            accessKey?: string | null | undefined;
            accountId?: string | null | undefined;
            apiKey?: string | null | undefined;
            apiKeyId?: string | null | undefined;
            caller?: string | null | undefined;
            cognitoAuthenticationProvider?: string | null | undefined;
            cognitoAuthenticationType?: string | null | undefined;
            cognitoIdentityId?: string | null | undefined;
            cognitoIdentityPoolId?: string | null | undefined;
            principalOrgId?: string | null | undefined;
            sourceIp?: string | undefined;
            user?: string | null | undefined;
            userAgent?: string | null | undefined;
            userArn?: string | null | undefined;
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | null | undefined;
        };
        requestId: string;
        requestTime: string;
        requestTimeEpoch: number;
        resourcePath: string;
        deploymentId?: string | null | undefined;
        authorizer?: {
            integrationLatency: number;
            principalId: string;
        } | {
            claims: Record<string, any>;
            scopes?: string[] | undefined;
        } | null | undefined;
        resourceId?: string | null | undefined;
        domainName?: string | null | undefined;
        domainPrefix?: string | null | undefined;
        extendedRequestId?: string | null | undefined;
        connectedAt?: number | null | undefined;
        connectionId?: string | null | undefined;
        eventType?: "CONNECT" | "MESSAGE" | "DISCONNECT" | null | undefined;
        messageDirection?: string | null | undefined;
        messageId?: string | null | undefined;
        routeKey?: string | null | undefined;
        operationName?: string | null | undefined;
    }, {
        path: string;
        httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        accountId: string;
        apiId: string;
        stage: string;
        protocol: string;
        identity: {
            accessKey?: string | null | undefined;
            accountId?: string | null | undefined;
            apiKey?: string | null | undefined;
            apiKeyId?: string | null | undefined;
            caller?: string | null | undefined;
            cognitoAuthenticationProvider?: string | null | undefined;
            cognitoAuthenticationType?: string | null | undefined;
            cognitoIdentityId?: string | null | undefined;
            cognitoIdentityPoolId?: string | null | undefined;
            principalOrgId?: string | null | undefined;
            sourceIp?: string | undefined;
            user?: string | null | undefined;
            userAgent?: string | null | undefined;
            userArn?: string | null | undefined;
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | null | undefined;
        };
        requestId: string;
        requestTime: string;
        requestTimeEpoch: number;
        resourcePath: string;
        deploymentId?: string | null | undefined;
        authorizer?: {
            integrationLatency: number;
            principalId: string;
        } | {
            claims: Record<string, any>;
            scopes?: string[] | undefined;
        } | null | undefined;
        resourceId?: string | null | undefined;
        domainName?: string | null | undefined;
        domainPrefix?: string | null | undefined;
        extendedRequestId?: string | null | undefined;
        connectedAt?: number | null | undefined;
        connectionId?: string | null | undefined;
        eventType?: "CONNECT" | "MESSAGE" | "DISCONNECT" | null | undefined;
        messageDirection?: string | null | undefined;
        messageId?: string | null | undefined;
        routeKey?: string | null | undefined;
        operationName?: string | null | undefined;
    }>;
    domainName: z.ZodOptional<z.ZodString>;
    deploymentId: z.ZodOptional<z.ZodString>;
    apiId: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    path: string;
    type: "REQUEST";
    httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
    headers: Record<string, string>;
    multiValueHeaders: Record<string, string[]>;
    queryStringParameters: Record<string, string>;
    multiValueQueryStringParameters: Record<string, string[]>;
    requestContext: {
        path: string;
        httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        accountId: string;
        apiId: string;
        stage: string;
        protocol: string;
        identity: {
            accessKey?: string | null | undefined;
            accountId?: string | null | undefined;
            apiKey?: string | null | undefined;
            apiKeyId?: string | null | undefined;
            caller?: string | null | undefined;
            cognitoAuthenticationProvider?: string | null | undefined;
            cognitoAuthenticationType?: string | null | undefined;
            cognitoIdentityId?: string | null | undefined;
            cognitoIdentityPoolId?: string | null | undefined;
            principalOrgId?: string | null | undefined;
            sourceIp?: string | undefined;
            user?: string | null | undefined;
            userAgent?: string | null | undefined;
            userArn?: string | null | undefined;
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | null | undefined;
        };
        requestId: string;
        requestTime: string;
        requestTimeEpoch: number;
        resourcePath: string;
        deploymentId?: string | null | undefined;
        authorizer?: {
            integrationLatency: number;
            principalId: string;
        } | {
            claims: Record<string, any>;
            scopes?: string[] | undefined;
        } | null | undefined;
        resourceId?: string | null | undefined;
        domainName?: string | null | undefined;
        domainPrefix?: string | null | undefined;
        extendedRequestId?: string | null | undefined;
        connectedAt?: number | null | undefined;
        connectionId?: string | null | undefined;
        eventType?: "CONNECT" | "MESSAGE" | "DISCONNECT" | null | undefined;
        messageDirection?: string | null | undefined;
        messageId?: string | null | undefined;
        routeKey?: string | null | undefined;
        operationName?: string | null | undefined;
    };
    resource: string;
    pathParameters: Record<string, string>;
    stageVariables: Record<string, string>;
    methodArn: string;
    apiId?: string | undefined;
    deploymentId?: string | undefined;
    domainName?: string | undefined;
}, {
    path: string;
    type: "REQUEST";
    httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
    headers: Record<string, string>;
    multiValueHeaders: Record<string, string[]>;
    queryStringParameters: Record<string, string>;
    multiValueQueryStringParameters: Record<string, string[]>;
    requestContext: {
        path: string;
        httpMethod: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        accountId: string;
        apiId: string;
        stage: string;
        protocol: string;
        identity: {
            accessKey?: string | null | undefined;
            accountId?: string | null | undefined;
            apiKey?: string | null | undefined;
            apiKeyId?: string | null | undefined;
            caller?: string | null | undefined;
            cognitoAuthenticationProvider?: string | null | undefined;
            cognitoAuthenticationType?: string | null | undefined;
            cognitoIdentityId?: string | null | undefined;
            cognitoIdentityPoolId?: string | null | undefined;
            principalOrgId?: string | null | undefined;
            sourceIp?: string | undefined;
            user?: string | null | undefined;
            userAgent?: string | null | undefined;
            userArn?: string | null | undefined;
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | null | undefined;
        };
        requestId: string;
        requestTime: string;
        requestTimeEpoch: number;
        resourcePath: string;
        deploymentId?: string | null | undefined;
        authorizer?: {
            integrationLatency: number;
            principalId: string;
        } | {
            claims: Record<string, any>;
            scopes?: string[] | undefined;
        } | null | undefined;
        resourceId?: string | null | undefined;
        domainName?: string | null | undefined;
        domainPrefix?: string | null | undefined;
        extendedRequestId?: string | null | undefined;
        connectedAt?: number | null | undefined;
        connectionId?: string | null | undefined;
        eventType?: "CONNECT" | "MESSAGE" | "DISCONNECT" | null | undefined;
        messageDirection?: string | null | undefined;
        messageId?: string | null | undefined;
        routeKey?: string | null | undefined;
        operationName?: string | null | undefined;
    };
    resource: string;
    pathParameters: Record<string, string>;
    stageVariables: Record<string, string>;
    methodArn: string;
    apiId?: string | undefined;
    deploymentId?: string | undefined;
    domainName?: string | undefined;
}>;
/**
 * A zod schema for an API Gateway Token Authorizer event
 *
 * @example
 * ```json
 * {
 *   "type": "TOKEN",
 *   "authorizationToken": "Bearer abcd1234",
 *   "methodArn": "arn:aws:execute-api:us-west-2:123456789012:ymy8tbxw7b/prod/GET/"
 * }
 * ```
 *
 * @see {@link https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-lambda-authorizer-input.html#w76aac15b9c21c25c21b3}
 */
declare const APIGatewayTokenAuthorizerEventSchema: z.ZodObject<{
    type: z.ZodLiteral<"TOKEN">;
    authorizationToken: z.ZodString;
    methodArn: z.ZodString;
}, "strip", z.ZodTypeAny, {
    type: "TOKEN";
    methodArn: string;
    authorizationToken: string;
}, {
    type: "TOKEN";
    methodArn: string;
    authorizationToken: string;
}>;
export { APIGatewayProxyEventSchema, APIGatewayRequestAuthorizerEventSchema, APIGatewayTokenAuthorizerEventSchema, APIGatewayEventRequestContextSchema, };
//# sourceMappingURL=api-gateway.d.ts.map