import { z } from 'zod';
/**
 * Zod schema for CloudFormation Custom Resource event with RequestType = 'Create'
 *
 * @example
 * ```json
 * {
 *   "RequestType": "Create",
 *   "ServiceToken": "arn:aws:lambda:us-east-1:xxx:function:xxxx-CrbuiltinfunctionidProvi-2vKAalSppmKe",
 *   "ResponseURL": "https://cloudformation-custom-resource-response-useast1.s3.amazonaws.com/7F%7Cb1f50fdfc25f3b",
 *   "StackId": "arn:aws:cloudformation:us-east-1:xxxx:stack/xxxx/271845b0-f2e8-11ed-90ac-0eeb25b8ae21",
 *   "RequestId": "xxxxx-d2a0-4dfb-ab1f-xxxxxx",
 *   "LogicalResourceId": "xxxxxxxxx",
 *   "ResourceType": "Custom::MyType",
 *   "ResourceProperties": {
 *     "ServiceToken": "arn:aws:lambda:us-east-1:xxxxx:function:xxxxx",
 *     "MyProps": "ss"
 *   }
 * }
 * ```
 * @see {@link types.CloudFormationCustomResourceCreateEvent | CloudFormationCustomResourceCreateEvent}
 * @see {@link https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/crpg-ref-requesttypes-create.html}
 */
declare const CloudFormationCustomResourceCreateSchema: z.ZodObject<z.objectUtil.extendShape<{
    ServiceToken: z.ZodString;
    ResponseURL: z.ZodString;
    StackId: z.ZodString;
    RequestId: z.ZodString;
    LogicalResourceId: z.ZodString;
    ResourceType: z.ZodString;
    ResourceProperties: z.ZodRecord<z.ZodString, z.ZodAny>;
}, {
    RequestType: z.ZodLiteral<"Create">;
}>, "strip", z.ZodTypeAny, {
    ServiceToken: string;
    ResponseURL: string;
    StackId: string;
    RequestId: string;
    LogicalResourceId: string;
    ResourceType: string;
    ResourceProperties: Record<string, any>;
    RequestType: "Create";
}, {
    ServiceToken: string;
    ResponseURL: string;
    StackId: string;
    RequestId: string;
    LogicalResourceId: string;
    ResourceType: string;
    ResourceProperties: Record<string, any>;
    RequestType: "Create";
}>;
/**
 * Zod schema for CloudFormation Custom Resource event with RequestType = 'Delete'
 *
 * @example
 * ```json
 * {
 *   "RequestType": "Delete",
 *   "ServiceToken": "arn:aws:lambda:us-east-1:xxx:function:xxxx-CrbuiltinfunctionidProvi-2vKAalSppmKe",
 *   "ResponseURL": "https://cloudformation-custom-resource-response-useast1.s3.amazonaws.com/7F%7Cb1f50fdfc25f3b",
 *   "StackId": "arn:aws:cloudformation:us-east-1:xxxx:stack/xxxx/271845b0-f2e8-11ed-90ac-0eeb25b8ae21",
 *   "RequestId": "xxxxx-d2a0-4dfb-ab1f-xxxxxx",
 *   "LogicalResourceId": "xxxxxxxxx",
 *   "ResourceType": "Custom::MyType",
 *   "ResourceProperties": {
 *     "ServiceToken": "arn:aws:lambda:us-east-1:xxxxx:function:xxxxx",
 *     "MyProps": "ss"
 *   }
 * }
 * ```
 * @see {@link types.CloudFormationCustomResourceDeleteEvent | CloudFormationCustomResourceDeleteEvent}
 * @see {@link https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/crpg-ref-requesttypes-delete.html}
 */
declare const CloudFormationCustomResourceDeleteSchema: z.ZodObject<z.objectUtil.extendShape<{
    ServiceToken: z.ZodString;
    ResponseURL: z.ZodString;
    StackId: z.ZodString;
    RequestId: z.ZodString;
    LogicalResourceId: z.ZodString;
    ResourceType: z.ZodString;
    ResourceProperties: z.ZodRecord<z.ZodString, z.ZodAny>;
}, {
    RequestType: z.ZodLiteral<"Delete">;
}>, "strip", z.ZodTypeAny, {
    ServiceToken: string;
    ResponseURL: string;
    StackId: string;
    RequestId: string;
    LogicalResourceId: string;
    ResourceType: string;
    ResourceProperties: Record<string, any>;
    RequestType: "Delete";
}, {
    ServiceToken: string;
    ResponseURL: string;
    StackId: string;
    RequestId: string;
    LogicalResourceId: string;
    ResourceType: string;
    ResourceProperties: Record<string, any>;
    RequestType: "Delete";
}>;
/**
 * Zod schema for CloudFormation Custom Resource event with RequestType = 'Update'
 *
 * @example
 * ```json
 * {
 *   "RequestType": "Update",
 *   "ServiceToken": "arn:aws:lambda:us-east-1:xxx:function:xxxx-CrbuiltinfunctionidProvi-2vKAalSppmKe",
 *   "ResponseURL": "https://cloudformation-custom-resource-response-useast1.s3.amazonaws.com/7F%7Cb1f50fdfc25f3b",
 *   "StackId": "arn:aws:cloudformation:us-east-1:xxxx:stack/xxxx/271845b0-f2e8-11ed-90ac-0eeb25b8ae21",
 *   "RequestId": "xxxxx-d2a0-4dfb-ab1f-xxxxxx",
 *   "LogicalResourceId": "xxxxxxxxx",
 *   "ResourceType": "Custom::MyType",
 *   "ResourceProperties": {
 *     "ServiceToken": "arn:aws:lambda:us-east-1:xxxxx:function:xxxxx",
 *     "MyProps": "new"
 *   },
 *   "OldResourceProperties": {
 *     "ServiceToken": "arn:aws:lambda:us-east-1:xxxxx:function:xxxxx-xxxx-xxx",
 *     "MyProps": "old"
 *   }
 * }
 * ```
 * @see {@link types.CloudFormationCustomResourceUpdateEvent | CloudFormationCustomResourceUpdateEvent}
 * @see {@link https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/crpg-ref-requesttypes-update.html}
 */
declare const CloudFormationCustomResourceUpdateSchema: z.ZodObject<z.objectUtil.extendShape<{
    ServiceToken: z.ZodString;
    ResponseURL: z.ZodString;
    StackId: z.ZodString;
    RequestId: z.ZodString;
    LogicalResourceId: z.ZodString;
    ResourceType: z.ZodString;
    ResourceProperties: z.ZodRecord<z.ZodString, z.ZodAny>;
}, {
    RequestType: z.ZodLiteral<"Update">;
    OldResourceProperties: z.ZodRecord<z.ZodString, z.ZodAny>;
}>, "strip", z.ZodTypeAny, {
    ServiceToken: string;
    ResponseURL: string;
    StackId: string;
    RequestId: string;
    LogicalResourceId: string;
    ResourceType: string;
    ResourceProperties: Record<string, any>;
    RequestType: "Update";
    OldResourceProperties: Record<string, any>;
}, {
    ServiceToken: string;
    ResponseURL: string;
    StackId: string;
    RequestId: string;
    LogicalResourceId: string;
    ResourceType: string;
    ResourceProperties: Record<string, any>;
    RequestType: "Update";
    OldResourceProperties: Record<string, any>;
}>;
export { CloudFormationCustomResourceCreateSchema, CloudFormationCustomResourceDeleteSchema, CloudFormationCustomResourceUpdateSchema, };
//# sourceMappingURL=cloudformation-custom-resource.d.ts.map