import { z } from 'zod';
/**
 * Zod schema for a Kafka record from an Kafka event.
 */
declare const KafkaRecordSchema: z.ZodObject<{
    topic: z.ZodString;
    partition: z.ZodNumber;
    offset: z.ZodNumber;
    timestamp: z.ZodNumber;
    timestampType: z.ZodString;
    key: z.ZodEffects<z.ZodString, string, string>;
    value: z.ZodEffects<z.ZodString, string, string>;
    headers: z.ZodArray<z.ZodRecord<z.ZodString, z.ZodEffects<z.ZodArray<z.ZodNumber, "many">, string, number[]>>, "many">;
}, "strip", z.ZodTypeAny, {
    value: string;
    headers: Record<string, string>[];
    timestamp: number;
    topic: string;
    partition: number;
    offset: number;
    timestampType: string;
    key: string;
}, {
    value: string;
    headers: Record<string, number[]>[];
    timestamp: number;
    topic: string;
    partition: number;
    offset: number;
    timestampType: string;
    key: string;
}>;
/** Zod schema for Kafka event from Self Managed Kafka
 *
 * @example
 * ```json
 * {
 *   "eventSource":"SelfManagedKafka",
 *   "bootstrapServers":"b-2.demo-cluster-1.a1bcde.c1.kafka.us-east-1.amazonaws.com:9092,b-1.demo-cluster-1.a1bcde.c1.kafka.us-east-1.amazonaws.com:9092",
 *   "records":{
 *      "mytopic-0":[
 *         {
 *            "topic":"mytopic",
 *            "partition":0,
 *            "offset":15,
 *            "timestamp":1545084650987,
 *            "timestampType":"CREATE_TIME",
 *            "key":"cmVjb3JkS2V5",
 *            "value":"eyJrZXkiOiJ2YWx1ZSJ9",
 *            "headers":[
 *               {
 *                  "headerKey":[
 *                     104,
 *                     101,
 *                     97,
 *                     100,
 *                     101,
 *                     114,
 *                     86,
 *                     97,
 *                     108,
 *                     117,
 *                     101
 *                  ]
 *               }
 *            ]
 *         }
 *      ]
 *   }
 * }
 * ```
 *
 * @see {@link types.KafkaSelfManagedEvent | KafkaSelfManagedEvent}
 * @see {@link https://docs.aws.amazon.com/lambda/latest/dg/with-kafka.html}
 */
declare const KafkaSelfManagedEventSchema: z.ZodObject<z.objectUtil.extendShape<{
    bootstrapServers: z.ZodOptional<z.ZodNullable<z.ZodEffects<z.ZodString, string[], string>>>;
    records: z.ZodRecord<z.ZodString, z.ZodArray<z.ZodObject<{
        topic: z.ZodString;
        partition: z.ZodNumber;
        offset: z.ZodNumber;
        timestamp: z.ZodNumber;
        timestampType: z.ZodString;
        key: z.ZodEffects<z.ZodString, string, string>;
        value: z.ZodEffects<z.ZodString, string, string>;
        headers: z.ZodArray<z.ZodRecord<z.ZodString, z.ZodEffects<z.ZodArray<z.ZodNumber, "many">, string, number[]>>, "many">;
    }, "strip", z.ZodTypeAny, {
        value: string;
        headers: Record<string, string>[];
        timestamp: number;
        topic: string;
        partition: number;
        offset: number;
        timestampType: string;
        key: string;
    }, {
        value: string;
        headers: Record<string, number[]>[];
        timestamp: number;
        topic: string;
        partition: number;
        offset: number;
        timestampType: string;
        key: string;
    }>, "many">>;
}, {
    eventSource: z.ZodLiteral<"SelfManagedKafka">;
}>, "strip", z.ZodTypeAny, {
    eventSource: "SelfManagedKafka";
    records: Record<string, {
        value: string;
        headers: Record<string, string>[];
        timestamp: number;
        topic: string;
        partition: number;
        offset: number;
        timestampType: string;
        key: string;
    }[]>;
    bootstrapServers?: string[] | null | undefined;
}, {
    eventSource: "SelfManagedKafka";
    records: Record<string, {
        value: string;
        headers: Record<string, number[]>[];
        timestamp: number;
        topic: string;
        partition: number;
        offset: number;
        timestampType: string;
        key: string;
    }[]>;
    bootstrapServers?: string | null | undefined;
}>;
/**
 * Zod schema for Kafka event from MSK
 *
 * @example
 * ```json
 * {
 *   "eventSource":"aws:kafka",
 *   "eventSourceArn":"arn:aws:kafka:us-east-1:0123456789019:cluster/SalesCluster/abcd1234-abcd-cafe-abab-9876543210ab-4",
 *   "bootstrapServers":"b-2.demo-cluster-1.a1bcde.c1.kafka.us-east-1.amazonaws.com:9092,b-1.demo-cluster-1.a1bcde.c1.kafka.us-east-1.amazonaws.com:9092",
 *   "records":{
 *      "mytopic-0":[
 *         {
 *            "topic":"mytopic",
 *            "partition":0,
 *            "offset":15,
 *            "timestamp":1545084650987,
 *            "timestampType":"CREATE_TIME",
 *            "key":"cmVjb3JkS2V5",
 *            "value":"eyJrZXkiOiJ2YWx1ZSJ9",
 *            "headers":[
 *               {
 *                  "headerKey":[
 *                     104,
 *                     101,
 *                     97,
 *                     100,
 *                     101,
 *                     114,
 *                     86,
 *                     97,
 *                     108,
 *                     117,
 *                     101
 *                  ]
 *               }
 *            ]
 *         }
 *      ]
 *   }
 * }
 * ```
 *
 * @see {@link types.KafkaMskEvent | KafkaMskEvent}
 * @see {@link https://docs.aws.amazon.com/lambda/latest/dg/with-msk.html}
 */
declare const KafkaMskEventSchema: z.ZodObject<z.objectUtil.extendShape<{
    bootstrapServers: z.ZodOptional<z.ZodNullable<z.ZodEffects<z.ZodString, string[], string>>>;
    records: z.ZodRecord<z.ZodString, z.ZodArray<z.ZodObject<{
        topic: z.ZodString;
        partition: z.ZodNumber;
        offset: z.ZodNumber;
        timestamp: z.ZodNumber;
        timestampType: z.ZodString;
        key: z.ZodEffects<z.ZodString, string, string>;
        value: z.ZodEffects<z.ZodString, string, string>;
        headers: z.ZodArray<z.ZodRecord<z.ZodString, z.ZodEffects<z.ZodArray<z.ZodNumber, "many">, string, number[]>>, "many">;
    }, "strip", z.ZodTypeAny, {
        value: string;
        headers: Record<string, string>[];
        timestamp: number;
        topic: string;
        partition: number;
        offset: number;
        timestampType: string;
        key: string;
    }, {
        value: string;
        headers: Record<string, number[]>[];
        timestamp: number;
        topic: string;
        partition: number;
        offset: number;
        timestampType: string;
        key: string;
    }>, "many">>;
}, {
    eventSource: z.ZodLiteral<"aws:kafka">;
    eventSourceArn: z.ZodString;
}>, "strip", z.ZodTypeAny, {
    eventSource: "aws:kafka";
    records: Record<string, {
        value: string;
        headers: Record<string, string>[];
        timestamp: number;
        topic: string;
        partition: number;
        offset: number;
        timestampType: string;
        key: string;
    }[]>;
    eventSourceArn: string;
    bootstrapServers?: string[] | null | undefined;
}, {
    eventSource: "aws:kafka";
    records: Record<string, {
        value: string;
        headers: Record<string, number[]>[];
        timestamp: number;
        topic: string;
        partition: number;
        offset: number;
        timestampType: string;
        key: string;
    }[]>;
    eventSourceArn: string;
    bootstrapServers?: string | null | undefined;
}>;
export { KafkaSelfManagedEventSchema, KafkaMskEventSchema, KafkaRecordSchema };
//# sourceMappingURL=kafka.d.ts.map