/**
 * Zod schema for Lambda Function URL follows the API Gateway HTTP APIs Payload Format Version 2.0.
 *
 * Keys related to API Gateway features not available in Function URL use a sentinel value (e.g.`routeKey`, `stage`).
 *
 * @example
 * ```json
 * {
 *  "version": "2.0",
 *  "routeKey": "$default",
 *  "rawPath": "/",
 *  "rawQueryString": "",
 *  "headers": {
 *    "sec-fetch-mode": "navigate",
 *    "x-amzn-tls-version": "TLSv1.2",
 *    "sec-fetch-site": "cross-site",
 *    "accept-language": "pt-BR,pt;q=0.9",
 *    "x-forwarded-proto": "https",
 *    "x-forwarded-port": "443",
 *    "x-forwarded-for": "123.123.123.123",
 *    "sec-fetch-user": "?1",
 *    "accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng;q=0.8,application/signed-exchange;v=b3;q=0.9",
 *    "x-amzn-tls-cipher-suite": "ECDHE-RSA-AES128-GCM-SHA256",
 *    "sec-ch-ua": "\" Not A;Brand\";v=\"99\", \"Chromium\";v=\"102\", \"Google Chrome\";v=\"102\"",
 *    "sec-ch-ua-mobile": "?0",
 *    "x-amzn-trace-id": "Root=1-62ecd163-5f302e550dcde3b12402207d",
 *    "sec-ch-ua-platform": "\"Linux\"",
 *    "host": "<url-id>.lambda-url.us-east-1.on.aws",
 *    "upgrade-insecure-requests": "1",
 *    "cache-control": "max-age=0",
 *    "accept-encoding": "gzip, deflate, br",
 *    "sec-fetch-dest": "document",
 *    "user-agent": "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/102.0.0.0 Safari/537.36"
 *  },
 *  "requestContext": {
 *    "accountId": "anonymous",
 *    "apiId": "<url-id>",
 *    "domainName": "<url-id>.lambda-url.us-east-1.on.aws",
 *    "domainPrefix": "<url-id>",
 *    "http": {
 *      "method": "GET",
 *      "path": "/",
 *      "protocol": "HTTP/1.1",
 *      "sourceIp": "123.123.123.123",
 *      "userAgent": "agent"
 *    },
 *    "requestId": "id",
 *    "routeKey": "$default",
 *    "stage": "$default",
 *    "time": "05/Aug/2022:08:14:39 +0000",
 *    "timeEpoch": 1659687279885
 *  },
 *  "isBase64Encoded": false
 * }
 * ```
 *
 * @see {@link types.LambdaFunctionUrlEvent | LambdaFunctionUrlEvent}
 * @see {@link https://docs.aws.amazon.com/lambda/latest/dg/urls-invocation.html#urls-payloads}
 */
declare const LambdaFunctionUrlSchema: import("zod").ZodObject<import("zod").objectUtil.extendShape<{
    version: import("zod").ZodString;
    routeKey: import("zod").ZodString;
    rawPath: import("zod").ZodString;
    rawQueryString: import("zod").ZodString;
    cookies: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString, "many">>;
    headers: import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>;
    queryStringParameters: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>;
    requestContext: import("zod").ZodObject<{
        accountId: import("zod").ZodString;
        apiId: import("zod").ZodString;
        authorizer: import("zod").ZodOptional<import("zod").ZodObject<{
            jwt: import("zod").ZodOptional<import("zod").ZodObject<{
                claims: import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodAny>;
                scopes: import("zod").ZodNullable<import("zod").ZodArray<import("zod").ZodString, "many">>;
            }, "strip", import("zod").ZodTypeAny, {
                claims: Record<string, any>;
                scopes: string[] | null;
            }, {
                claims: Record<string, any>;
                scopes: string[] | null;
            }>>;
            iam: import("zod").ZodOptional<import("zod").ZodObject<{
                accessKey: import("zod").ZodOptional<import("zod").ZodString>;
                accountId: import("zod").ZodOptional<import("zod").ZodString>;
                callerId: import("zod").ZodOptional<import("zod").ZodString>;
                principalOrgId: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                userArn: import("zod").ZodOptional<import("zod").ZodString>;
                userId: import("zod").ZodOptional<import("zod").ZodString>;
                cognitoIdentity: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodObject<{
                    amr: import("zod").ZodArray<import("zod").ZodString, "many">;
                    identityId: import("zod").ZodString;
                    identityPoolId: import("zod").ZodString;
                }, "strip", import("zod").ZodTypeAny, {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                }, {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                }>>>;
            }, "strip", import("zod").ZodTypeAny, {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            }, {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            }>>;
            lambda: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodAny>>>;
        }, "strip", import("zod").ZodTypeAny, {
            jwt?: {
                claims: Record<string, any>;
                scopes: string[] | null;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | null | undefined;
        }, {
            jwt?: {
                claims: Record<string, any>;
                scopes: string[] | null;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | null | undefined;
        }>>;
        authentication: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodObject<{
            clientCert: import("zod").ZodOptional<import("zod").ZodObject<{
                clientCertPem: import("zod").ZodString;
                subjectDN: import("zod").ZodString;
                issuerDN: import("zod").ZodString;
                serialNumber: import("zod").ZodString;
                validity: import("zod").ZodObject<{
                    notBefore: import("zod").ZodString;
                    notAfter: import("zod").ZodString;
                }, "strip", import("zod").ZodTypeAny, {
                    notBefore: string;
                    notAfter: string;
                }, {
                    notBefore: string;
                    notAfter: string;
                }>;
            }, "strip", import("zod").ZodTypeAny, {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            }, {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            }>>;
        }, "strip", import("zod").ZodTypeAny, {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        }, {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        }>>>;
        domainName: import("zod").ZodString;
        domainPrefix: import("zod").ZodString;
        http: import("zod").ZodObject<{
            method: import("zod").ZodEnum<["GET", "POST", "PUT", "PATCH", "DELETE", "HEAD", "OPTIONS"]>;
            path: import("zod").ZodString;
            protocol: import("zod").ZodString;
            sourceIp: import("zod").ZodString;
            userAgent: import("zod").ZodString;
        }, "strip", import("zod").ZodTypeAny, {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        }, {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        }>;
        requestId: import("zod").ZodString;
        routeKey: import("zod").ZodString;
        stage: import("zod").ZodString;
        time: import("zod").ZodString;
        timeEpoch: import("zod").ZodNumber;
    }, "strip", import("zod").ZodTypeAny, {
        time: string;
        accountId: string;
        apiId: string;
        stage: string;
        requestId: string;
        domainName: string;
        domainPrefix: string;
        routeKey: string;
        http: {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        };
        timeEpoch: number;
        authorizer?: {
            jwt?: {
                claims: Record<string, any>;
                scopes: string[] | null;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | null | undefined;
        } | undefined;
        authentication?: {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        } | null | undefined;
    }, {
        time: string;
        accountId: string;
        apiId: string;
        stage: string;
        requestId: string;
        domainName: string;
        domainPrefix: string;
        routeKey: string;
        http: {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        };
        timeEpoch: number;
        authorizer?: {
            jwt?: {
                claims: Record<string, any>;
                scopes: string[] | null;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | null | undefined;
        } | undefined;
        authentication?: {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        } | null | undefined;
    }>;
    body: import("zod").ZodOptional<import("zod").ZodString>;
    pathParameters: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>>;
    isBase64Encoded: import("zod").ZodBoolean;
    stageVariables: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>>;
}, {}>, "strip", import("zod").ZodTypeAny, {
    isBase64Encoded: boolean;
    headers: Record<string, string>;
    requestContext: {
        time: string;
        accountId: string;
        apiId: string;
        stage: string;
        requestId: string;
        domainName: string;
        domainPrefix: string;
        routeKey: string;
        http: {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        };
        timeEpoch: number;
        authorizer?: {
            jwt?: {
                claims: Record<string, any>;
                scopes: string[] | null;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | null | undefined;
        } | undefined;
        authentication?: {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        } | null | undefined;
    };
    routeKey: string;
    version: string;
    rawPath: string;
    rawQueryString: string;
    body?: string | undefined;
    queryStringParameters?: Record<string, string> | undefined;
    pathParameters?: Record<string, string> | null | undefined;
    stageVariables?: Record<string, string> | null | undefined;
    cookies?: string[] | undefined;
}, {
    isBase64Encoded: boolean;
    headers: Record<string, string>;
    requestContext: {
        time: string;
        accountId: string;
        apiId: string;
        stage: string;
        requestId: string;
        domainName: string;
        domainPrefix: string;
        routeKey: string;
        http: {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        };
        timeEpoch: number;
        authorizer?: {
            jwt?: {
                claims: Record<string, any>;
                scopes: string[] | null;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | null | undefined;
        } | undefined;
        authentication?: {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        } | null | undefined;
    };
    routeKey: string;
    version: string;
    rawPath: string;
    rawQueryString: string;
    body?: string | undefined;
    queryStringParameters?: Record<string, string> | undefined;
    pathParameters?: Record<string, string> | null | undefined;
    stageVariables?: Record<string, string> | null | undefined;
    cookies?: string[] | undefined;
}>;
export { LambdaFunctionUrlSchema };
//# sourceMappingURL=lambda.d.ts.map